import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32ras import *
@pytest.mark.xfail
def test_CreatePhonebookEntry():
    CreatePhonebookEntry()     



@pytest.mark.xfail
def test_Dial():
    Dial()     



@pytest.mark.xfail
def test_EditPhonebookEntry():
    EditPhonebookEntry()     



def test_EnumConnections():
    EnumConnections()     



def test_EnumEntries():
    EnumEntries()     



@pytest.mark.xfail
def test_GetConnectStatus():
    GetConnectStatus()     



@pytest.mark.xfail
def test_GetEntryDialParams():
    GetEntryDialParams()     



@pytest.mark.xfail
def test_GetErrorString():
    GetErrorString()     



@pytest.mark.xfail
def test_HangUp():
    HangUp()     



@pytest.mark.xfail
def test_IsHandleValid():
    IsHandleValid()     



def test_RASDIALEXTENSIONS():
    RASDIALEXTENSIONS()     



@pytest.mark.xfail
def test_SetEntryDialParams():
    SetEntryDialParams()     





import pytest

# from isapi.install import *


@pytest.mark.skip
def test_AddExtensionFiles():
    AddExtensionFiles()


@pytest.mark.skip
def test_AssignScriptMaps():
    AssignScriptMaps()


@pytest.mark.skip
def test_FindWebServer():
    FindWebServer()


@pytest.mark.skip
def test_GetWebServer():
    GetWebServer()


@pytest.mark.skip
def test_HandleCommandLine():
    HandleCommandLine()


@pytest.mark.skip
def test_InstallModule():
    InstallModule()


@pytest.mark.skip
def test_LocateWebServerPath():
    LocateWebServerPath()


@pytest.mark.skip
def test_MergeStandardOptions():
    MergeStandardOptions()


@pytest.mark.skip
def test_RemoveScriptMaps():
    RemoveScriptMaps()


@pytest.mark.skip
def test_UninstallModule():
    UninstallModule()


@pytest.mark.skip
def test_get_unique_items():
    get_unique_items()


@pytest.mark.skip
def test_split_path():
    split_path()



# Test AXScripting the best we can in an automated fashion...
import os
import sys
import win32api

import pytest
import win32com.axscript
import win32com.axscript.client
import win32com.test.util

verbose = "-v" in sys.argv


class AXScript(win32com.test.util.TestCase):
    def setUp(self):
        file = win32api.GetFullPathName(
            os.path.join(win32com.axscript.client.__path__[0], "pyscript.py"))
        from win32com.test.util import RegisterPythonServer
        self.verbose = verbose
        RegisterPythonServer(file, 'python', verbose=self.verbose)

    @pytest.mark.xfail
    def testHost(self):
        file = win32api.GetFullPathName(
            os.path.join(win32com.axscript.__path__[0], "test\\testHost.py"))
        cmd = '%s "%s"' % (win32api.GetModuleFileName(0), file)
        if verbose:
            print("Testing Python Scripting host")
        win32com.test.util.ExecuteShellCommand(cmd, self)

    @pytest.mark.xfail
    def testCScript(self):
        file = win32api.GetFullPathName(
            os.path.join(win32com.axscript.__path__[0],
                         "Demos\\Client\\wsh\\test.pys"))
        cmd = 'cscript.exe "%s"' % (file)
        if verbose:
            print("Testing Windows Scripting host with Python script")
        win32com.test.util.ExecuteShellCommand(cmd, self)


if __name__ == '__main__':
    win32com.test.util.testmain()



import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest

from mapi import *

@pytest.mark.xfail
def test_BinFromHex():
    BinFromHex()     



@pytest.mark.xfail
def test_CloseIMsgSession():
    CloseIMsgSession()     



@pytest.mark.xfail
def test_HexFromBin():
    HexFromBin()     



@pytest.mark.xfail
def test_HrQueryAllRows():
    HrQueryAllRows()     



@pytest.mark.xfail
def test_MAPIAdminProfiles():
    MAPIAdminProfiles()     



@pytest.mark.xfail
def test_MAPIInitialize():
    MAPIInitialize()     



@pytest.mark.xfail
def test_MAPILogonEx():
    MAPILogonEx()     


@pytest.mark.skip
def test_MAPIUninitialize():
    MAPIUninitialize()     



@pytest.mark.xfail
def test_OpenIMsgOnIStg():
    OpenIMsgOnIStg()     


@pytest.mark.skip
def test_OpenIMsgSession():
    OpenIMsgSession()     



@pytest.mark.xfail
def test_RTFStreamToHTML():
    RTFStreamToHTML()     



@pytest.mark.xfail
def test_RTFSync():
    RTFSync()     



@pytest.mark.xfail
def test_WrapCompressedRTFStream():
    WrapCompressedRTFStream()     





import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32event import *
@pytest.mark.xfail
def test_CancelWaitableTimer():
    CancelWaitableTimer()     



@pytest.mark.xfail
def test_CreateEvent():
    CreateEvent()     



@pytest.mark.xfail
def test_CreateMutex():
    CreateMutex()     



@pytest.mark.xfail
def test_CreateSemaphore():
    CreateSemaphore()     



@pytest.mark.xfail
def test_MsgWaitForMultipleObjects():
    MsgWaitForMultipleObjects()     



@pytest.mark.xfail
def test_MsgWaitForMultipleObjectsEx():
    MsgWaitForMultipleObjectsEx()     



@pytest.mark.xfail
def test_OpenEvent():
    OpenEvent()     



@pytest.mark.xfail
def test_OpenMutex():
    OpenMutex()     



@pytest.mark.xfail
def test_OpenSemaphore():
    OpenSemaphore()     



@pytest.mark.xfail
def test_OpenWaitableTimer():
    OpenWaitableTimer()     



@pytest.mark.xfail
def test_PulseEvent():
    PulseEvent()     



@pytest.mark.xfail
def test_ReleaseMutex():
    ReleaseMutex()     



@pytest.mark.xfail
def test_ReleaseSemaphore():
    ReleaseSemaphore()     



@pytest.mark.xfail
def test_ResetEvent():
    ResetEvent()     



@pytest.mark.xfail
def test_SetEvent():
    SetEvent()     



@pytest.mark.xfail
def test_SetWaitableTimer():
    SetWaitableTimer()     



@pytest.mark.xfail
def test_WaitForInputIdle():
    WaitForInputIdle()     



@pytest.mark.xfail
def test_WaitForMultipleObjects():
    WaitForMultipleObjects()     



@pytest.mark.xfail
def test_WaitForMultipleObjectsEx():
    WaitForMultipleObjectsEx()     



@pytest.mark.xfail
def test_WaitForSingleObject():
    WaitForSingleObject()     



@pytest.mark.xfail
def test_WaitForSingleObjectEx():
    WaitForSingleObjectEx()     





import pytest
import pytest
import pytest
import pytest
import pytest
from win32lz import *
@pytest.mark.xfail
def test_Close():
    Close()     



@pytest.mark.xfail
def test_Copy():
    Copy()     



@pytest.mark.xfail
def test_GetExpandedName():
    GetExpandedName()     



@pytest.mark.xfail
def test_Init():
    Init()     



@pytest.mark.xfail
def test_OpenFile():
    OpenFile()     





import pytest

from win32evtlog import *


@pytest.mark.xfail
def test_BackupEventLog():
    BackupEventLog()


@pytest.mark.xfail
def test_ClearEventLog():
    ClearEventLog()


@pytest.mark.xfail
def test_CloseEventLog():
    CloseEventLog()


@pytest.mark.xfail
def test_DeregisterEventSource():
    DeregisterEventSource()


@pytest.mark.xfail
def test_GetNumberOfEventLogRecords():
    GetNumberOfEventLogRecords()


@pytest.mark.xfail
def test_GetOldestEventLogRecord():
    GetOldestEventLogRecord()


@pytest.mark.xfail
def test_NotifyChangeEventLog():
    NotifyChangeEventLog()


@pytest.mark.xfail
def test_OpenBackupEventLog():
    OpenBackupEventLog()


@pytest.mark.xfail
def test_OpenEventLog():
    OpenEventLog()


@pytest.mark.xfail
def test_ReadEventLog():
    ReadEventLog()


@pytest.mark.xfail
def test_RegisterEventSource():
    RegisterEventSource()


@pytest.mark.xfail
def test_ReportEvent():
    ReportEvent()



# Test makepy - try and run it over every OCX in the windows system directory.

import sys
import traceback

import pythoncom
import win32com.test.util
import winerror
from win32com.client import makepy, selecttlb, gencache


def TestBuildAll(verbose=1):
    num = 0
    tlbInfos = selecttlb.EnumTlbs()
    for info in tlbInfos:
        if verbose:
            print("%s (%s)" % (info.desc, info.dll))
        try:
            makepy.GenerateFromTypeLibSpec(info)
            #          sys.stderr.write("Attr typeflags for coclass referenced object %s=%d (%d), typekind=%d\n" % (name, refAttr.wTypeFlags, refAttr.wTypeFlags & pythoncom.TYPEFLAG_FDUAL,refAttr.typekind))
            num += 1
        except pythoncom.com_error as details:
            # Ignore these 2 errors, as the are very common and can obscure
            # useful warnings.
            if details.hresult not in [winerror.TYPE_E_CANTLOADLIBRARY,
                                       winerror.TYPE_E_LIBNOTREGISTERED]:
                print("** COM error on", info.desc)
                print(details)
        except KeyboardInterrupt:
            print("Interrupted!")
            raise KeyboardInterrupt
        except:
            print("Failed:", info.desc)
            traceback.print_exc()
        if makepy.bForDemandDefault:
            # This only builds enums etc by default - build each
            # interface manually
            tinfo = (info.clsid, info.lcid, info.major, info.minor)
            mod = gencache.EnsureModule(
                info.clsid, info.lcid, info.major, info.minor)
            for name in mod.NamesToIIDMap.keys():
                makepy.GenerateChildFromTypeLibSpec(name, tinfo)
    return num


def TestAll(verbose=0):
    num = TestBuildAll(verbose)
    print("Generated and imported", num, "modules")
    win32com.test.util.CheckClean()


if __name__ == '__main__':
    TestAll("-q" not in sys.argv)



import sys
import json

wrapper_file = open(sys.argv[1], 'r+')

line = '#'
while line.startswith('#'):
    pos = wrapper_file.tell()
    line = wrapper_file.readline()
    
wrapper_file.seek(pos)

wrapper = json.load(wrapper_file)

for i, item in enumerate(wrapper['captures']):
    wrapper['captures'][i].setdefault('stdout', '')
    wrapper['captures'][i].setdefault('stderr', '')
    if not wrapper['captures'][i]['stdout']:
        wrapper['captures'][i]['stdout'] = wrapper['captures'][0]['stdout']
    if not wrapper['captures'][i]['stderr']:
        wrapper['captures'][i]['stderr'] = wrapper['captures'][0]['stderr']

wrapper_file.seek(0)
wrapper_file.truncate()
json.dump(wrapper, wrapper_file, indent=4)



# tests for win32gui
import array
import operator
import sys
import unittest
import win32gui

import pytest
import pywin32_testutil


# theoretically should be in pywin32_testutil, but this is the only place
# that currently needs such a function...


def ob2bytes(ob):
    if sys.version_info < (3, 0):
        return str(buffer(ob))
    # py3k.
    return bytes(ob)


class TestPyGetString(unittest.TestCase):
    def test_get_string(self):
        # test invalid addresses cause a ValueError rather than crash!
        with pytest.raises(ValueError):
            win32gui.PyGetString(0)
        with pytest.raises(ValueError):
            win32gui.PyGetString(1)
        with pytest.raises(ValueError):
            win32gui.PyGetString(1, 1)


class TestPyGetMemory(unittest.TestCase):
    def test_ob(self):
        # Check the PyGetMemory result and a bytes string can be compared
        test_data = pywin32_testutil.str2bytes("\0\1\2\3\4\5\6")
        c = array.array("b", test_data)
        addr, buflen = c.buffer_info()
        got = win32gui.PyGetMemory(addr, buflen)
        assert len(got) == len(test_data)
        assert ob2bytes(got) == test_data

    @pytest.mark.xfail
    def test_memory_index(self):
        # Check we can index into the buffer object returned by PyGetMemory
        test_data = pywin32_testutil.str2bytes("\0\1\2\3\4\5\6")
        c = array.array("b", test_data)
        addr, buflen = c.buffer_info()
        got = win32gui.PyGetMemory(addr, buflen)
        assert got[0] == pywin32_testutil.str2bytes('\0')

    def test_memory_slice(self):
        # Check we can slice the buffer object returned by PyGetMemory
        test_data = pywin32_testutil.str2bytes("\0\1\2\3\4\5\6")
        c = array.array("b", test_data)
        addr, buflen = c.buffer_info()
        got = win32gui.PyGetMemory(addr, buflen)
        assert got[0:3] == pywin32_testutil.str2bytes('\0\1\2')

    @pytest.mark.xfail
    def test_real_view(self):
        # Do the PyGetMemory, then change the original memory, then ensure
        # the initial object we fetched sees the new value.
        test_data = pywin32_testutil.str2bytes("\0\1\2\3\4\5\6")
        c = array.array("b", test_data)
        addr, buflen = c.buffer_info()
        got = win32gui.PyGetMemory(addr, buflen)
        assert got[0] == pywin32_testutil.str2bytes('\0')
        new = pywin32_testutil.str2bytes('\1')
        c[0] = 1
        assert got[0] == new

    def test_memory_not_writable(self):
        # Check the buffer object fetched by PyGetMemory isn't writable.
        test_data = pywin32_testutil.str2bytes("\0\1\2\3\4\5\6")
        c = array.array("b", test_data)
        addr, buflen = c.buffer_info()
        got = win32gui.PyGetMemory(addr, buflen)
        new = pywin32_testutil.str2bytes('\1')
        with pytest.raises(TypeError):
            operator.setitem(got, 0, new)


if __name__ == '__main__':
    unittest.main()



import pytest

from contextlib import suppress

with suppress(ImportError):
    from win32gui import *


@pytest.mark.skip
def test_AbortPath():
    AbortPath()


@pytest.mark.skip
def test_AlphaBlend():
    AlphaBlend()


@pytest.mark.skip
def test_AngleArc():
    AngleArc()


@pytest.mark.skip
def test_AngleArc():
    AngleArc()


@pytest.mark.skip
def test_AnimateWindow():
    AnimateWindow()


@pytest.mark.skip
def test_AppendMenu():
    AppendMenu()


@pytest.mark.skip
def test_Arc():
    Arc()


@pytest.mark.skip
def test_ArcTo():
    ArcTo()


@pytest.mark.skip
def test_BeginPaint():
    BeginPaint()


@pytest.mark.skip
def test_BeginPath():
    BeginPath()


@pytest.mark.skip
def test_BitBlt():
    BitBlt()


@pytest.mark.skip
def test_BringWindowToTop():
    BringWindowToTop()


@pytest.mark.skip
def test_CallWindowProc():
    CallWindowProc()


@pytest.mark.skip
def test_CheckMenuItem():
    CheckMenuItem()


@pytest.mark.skip
def test_CheckMenuRadioItem():
    CheckMenuRadioItem()


@pytest.mark.skip
def test_ChildWindowFromPoint():
    ChildWindowFromPoint()


@pytest.mark.skip
def test_ChildWindowFromPoint():
    ChildWindowFromPoint()


@pytest.mark.skip
def test_Chord():
    Chord()


@pytest.mark.skip
def test_ClientToScreen():
    ClientToScreen()


@pytest.mark.skip
def test_CloseFigure():
    CloseFigure()


@pytest.mark.skip
def test_CloseWindow():
    CloseWindow()


@pytest.mark.skip
def test_CombineRgn():
    CombineRgn()


@pytest.mark.skip
def test_CombineTransform():
    CombineTransform()


@pytest.mark.skip
def test_CommDlgExtendedError():
    CommDlgExtendedError()


@pytest.mark.skip
def test_CopyIcon():
    CopyIcon()


@pytest.mark.skip
def test_CreateAcceleratorTable():
    CreateAcceleratorTable()


@pytest.mark.skip
def test_CreateBitmap():
    CreateBitmap()


@pytest.mark.skip
def test_CreateBrushIndirect():
    CreateBrushIndirect()


@pytest.mark.skip
def test_CreateCaret():
    CreateCaret()


@pytest.mark.skip
def test_CreateCompatibleBitmap():
    CreateCompatibleBitmap()


@pytest.mark.skip
def test_CreateCompatibleDC():
    CreateCompatibleDC()


@pytest.mark.skip
def test_CreateDC():
    CreateDC()


@pytest.mark.skip
def test_CreateDialogIndirect():
    CreateDialogIndirect()


@pytest.mark.skip
def test_CreateEllipticRgnIndirect():
    CreateEllipticRgnIndirect()


@pytest.mark.skip
def test_CreateFontIndirect():
    CreateFontIndirect()


@pytest.mark.skip
def test_CreateHatchBrush():
    CreateHatchBrush()


@pytest.mark.skip
def test_CreateIconFromResource():
    CreateIconFromResource()


@pytest.mark.skip
def test_CreateIconIndirect():
    CreateIconIndirect()


@pytest.mark.skip
def test_CreateMenu():
    CreateMenu()


@pytest.mark.skip
def test_CreatePatternBrush():
    CreatePatternBrush()


@pytest.mark.skip
def test_CreatePen():
    CreatePen()


@pytest.mark.skip
def test_CreatePolygonRgn():
    CreatePolygonRgn()


@pytest.mark.skip
def test_CreatePopupMenu():
    CreatePopupMenu()


@pytest.mark.skip
def test_CreateRectRgnIndirect():
    CreateRectRgnIndirect()


@pytest.mark.skip
def test_CreateRoundRectRgn():
    CreateRoundRectRgn()


@pytest.mark.skip
def test_CreateSolidBrush():
    CreateSolidBrush()


@pytest.mark.skip
def test_CreateWindow():
    CreateWindow()


@pytest.mark.skip
def test_CreateWindowEx():
    CreateWindowEx()


@pytest.mark.skip
def test_DefWindowProc():
    DefWindowProc()


@pytest.mark.skip
def test_DeleteDC():
    DeleteDC()


@pytest.mark.skip
def test_DeleteMenu():
    DeleteMenu()


@pytest.mark.skip
def test_DeleteObject():
    DeleteObject()


@pytest.mark.skip
def test_DestroyAccleratorTable():
    DestroyAccleratorTable()


@pytest.mark.skip
def test_DestroyCaret():
    DestroyCaret()


@pytest.mark.skip
def test_DestroyIcon():
    DestroyIcon()


@pytest.mark.skip
def test_DestroyMenu():
    DestroyMenu()


@pytest.mark.skip
def test_DestroyWindow():
    DestroyWindow()


@pytest.mark.skip
def test_DialogBox():
    DialogBox()


@pytest.mark.skip
def test_DialogBoxIndirect():
    DialogBoxIndirect()


@pytest.mark.skip
def test_DialogBoxIndirectParam():
    DialogBoxIndirectParam()


@pytest.mark.skip
def test_DialogBoxIndirectParam():
    DialogBoxIndirectParam()


@pytest.mark.skip
def test_DialogBoxParam():
    DialogBoxParam()


@pytest.mark.skip
def test_DispatchMessage():
    DispatchMessage()


@pytest.mark.skip
def test_DragAcceptFiles():
    DragAcceptFiles()


@pytest.mark.skip
def test_DragDetect():
    DragDetect()


@pytest.mark.skip
def test_DrawAnimatedRects():
    DrawAnimatedRects()


@pytest.mark.skip
def test_DrawEdge():
    DrawEdge()


@pytest.mark.skip
def test_DrawFocusRect():
    DrawFocusRect()


@pytest.mark.skip
def test_DrawIcon():
    DrawIcon()


@pytest.mark.skip
def test_DrawIconEx():
    DrawIconEx()


@pytest.mark.skip
def test_DrawMenuBar():
    DrawMenuBar()


@pytest.mark.skip
def test_DrawText():
    DrawText()


@pytest.mark.skip
def test_DrawTextW():
    DrawTextW()


@pytest.mark.skip
def test_Ellipse():
    Ellipse()


@pytest.mark.skip
def test_EnableMenuItem():
    EnableMenuItem()


@pytest.mark.skip
def test_EnableWindow():
    EnableWindow()


@pytest.mark.skip
def test_EndDialog():
    EndDialog()


@pytest.mark.skip
def test_EndPaint():
    EndPaint()


@pytest.mark.skip
def test_EndPath():
    EndPath()


@pytest.mark.skip
def test_EnumChildWindows():
    EnumChildWindows()


@pytest.mark.skip
def test_EnumFontFamilies():
    EnumFontFamilies()


@pytest.mark.skip
def test_EnumPropsEx():
    EnumPropsEx()


@pytest.mark.skip
def test_EnumThreadWindows():
    EnumThreadWindows()


@pytest.mark.skip
def test_EnumWindows():
    EnumWindows()


@pytest.mark.skip
def test_EqualRgn():
    EqualRgn()


@pytest.mark.skip
def test_ExtCreatePen():
    ExtCreatePen()


@pytest.mark.skip
def test_ExtFloodFill():
    ExtFloodFill()


@pytest.mark.skip
def test_ExtTextOut():
    ExtTextOut()


@pytest.mark.skip
def test_ExtractIcon():
    ExtractIcon()


@pytest.mark.skip
def test_ExtractIconEx():
    ExtractIconEx()


@pytest.mark.skip
def test_FillPath():
    FillPath()


@pytest.mark.skip
def test_FillRect():
    FillRect()


@pytest.mark.skip
def test_FillRgn():
    FillRgn()


@pytest.mark.skip
def test_FindWindow():
    FindWindow()


@pytest.mark.skip
def test_FindWindowEx():
    FindWindowEx()


@pytest.mark.skip
def test_FlashWindow():
    FlashWindow()


@pytest.mark.skip
def test_FlashWindowEx():
    FlashWindowEx()


@pytest.mark.skip
def test_FlattenPath():
    FlattenPath()


@pytest.mark.skip
def test_FrameRect():
    FrameRect()


@pytest.mark.skip
def test_FrameRgn():
    FrameRgn()


@pytest.mark.skip
def test_GetActiveWindow():
    GetActiveWindow()


@pytest.mark.skip
def test_GetArcDirection():
    GetArcDirection()


@pytest.mark.skip
def test_GetBkColor():
    GetBkColor()


@pytest.mark.skip
def test_GetBkMode():
    GetBkMode()


@pytest.mark.skip
def test_GetCapture():
    GetCapture()


@pytest.mark.skip
def test_GetCaretPos():
    GetCaretPos()


@pytest.mark.skip
def test_GetClassLong():
    GetClassLong()


@pytest.mark.skip
def test_GetClassName():
    GetClassName()


@pytest.mark.skip
def test_GetClientRect():
    GetClientRect()


@pytest.mark.skip
def test_GetCurrentObject():
    GetCurrentObject()


@pytest.mark.skip
def test_GetCurrentPositionEx():
    GetCurrentPositionEx()


@pytest.mark.skip
def test_GetCursor():
    GetCursor()


@pytest.mark.skip
def test_GetCursorInfo():
    GetCursorInfo()


@pytest.mark.skip
def test_GetCursorPos():
    GetCursorPos()


@pytest.mark.skip
def test_GetDC():
    GetDC()


@pytest.mark.skip
def test_GetDesktopWindow():
    GetDesktopWindow()


@pytest.mark.skip
def test_GetDlgCtrlID():
    GetDlgCtrlID()


@pytest.mark.skip
def test_GetDlgItem():
    GetDlgItem()


@pytest.mark.skip
def test_GetDlgItemInt():
    GetDlgItemInt()


@pytest.mark.skip
def test_GetDlgItemText():
    GetDlgItemText()


@pytest.mark.skip
def test_GetDoubleClickTime():
    GetDoubleClickTime()


@pytest.mark.skip
def test_GetFocus():
    GetFocus()


@pytest.mark.skip
def test_GetForegroundWindow():
    GetForegroundWindow()


@pytest.mark.skip
def test_GetGraphicsMode():
    GetGraphicsMode()


@pytest.mark.skip
def test_GetIconInfo():
    GetIconInfo()


@pytest.mark.skip
def test_GetLayeredWindowAttributes():
    GetLayeredWindowAttributes()


@pytest.mark.skip
def test_GetLayout():
    GetLayout()


@pytest.mark.skip
def test_GetMapMode():
    GetMapMode()


@pytest.mark.skip
def test_GetMenu():
    GetMenu()


@pytest.mark.skip
def test_GetMenuDefaultItem():
    GetMenuDefaultItem()


@pytest.mark.skip
def test_GetMenuInfo():
    GetMenuInfo()


@pytest.mark.skip
def test_GetMenuItemCount():
    GetMenuItemCount()


@pytest.mark.skip
def test_GetMenuItemID():
    GetMenuItemID()


@pytest.mark.skip
def test_GetMenuItemInfo():
    GetMenuItemInfo()


@pytest.mark.skip
def test_GetMenuItemRect():
    GetMenuItemRect()


@pytest.mark.skip
def test_GetMenuState():
    GetMenuState()


@pytest.mark.skip
def test_GetMessage():
    GetMessage()


@pytest.mark.skip
def test_GetMiterLimit():
    GetMiterLimit()


@pytest.mark.skip
def test_GetNextDlgGroupItem():
    GetNextDlgGroupItem()


@pytest.mark.skip
def test_GetNextDlgTabItem():
    GetNextDlgTabItem()


@pytest.mark.skip
def test_GetObject():
    GetObject()


@pytest.mark.skip
def test_GetObjectType():
    GetObjectType()


@pytest.mark.skip
def test_GetOpenFileName():
    GetOpenFileName()


@pytest.mark.skip
def test_GetOpenFileNameW():
    GetOpenFileNameW()


@pytest.mark.skip
def test_GetParent():
    GetParent()


@pytest.mark.skip
def test_GetPath():
    GetPath()


@pytest.mark.skip
def test_GetPixel():
    GetPixel()


@pytest.mark.skip
def test_GetPolyFillMode():
    GetPolyFillMode()


@pytest.mark.skip
def test_GetROP2():
    GetROP2()


@pytest.mark.skip
def test_GetRgnBox():
    GetRgnBox()


@pytest.mark.skip
def test_GetSaveFileNameW():
    GetSaveFileNameW()


@pytest.mark.skip
def test_GetScrollInfo():
    GetScrollInfo()


@pytest.mark.skip
def test_GetStockObject():
    GetStockObject()


@pytest.mark.skip
def test_GetStretchBltMode():
    GetStretchBltMode()


@pytest.mark.skip
def test_GetSubMenu():
    GetSubMenu()


@pytest.mark.skip
def test_GetSysColor():
    GetSysColor()


@pytest.mark.skip
def test_GetSysColorBrush():
    GetSysColorBrush()


@pytest.mark.skip
def test_GetSystemMenu():
    GetSystemMenu()


@pytest.mark.skip
def test_GetTextAlign():
    GetTextAlign()


@pytest.mark.skip
def test_GetTextCharacterExtra():
    GetTextCharacterExtra()


@pytest.mark.skip
def test_GetTextColor():
    GetTextColor()


@pytest.mark.skip
def test_GetTextExtentPoint32():
    GetTextExtentPoint32()


@pytest.mark.skip
def test_GetTextFace():
    GetTextFace()


@pytest.mark.skip
def test_GetTextMetrics():
    GetTextMetrics()


@pytest.mark.skip
def test_GetUpdateRgn():
    GetUpdateRgn()


@pytest.mark.skip
def test_GetViewportExtEx():
    GetViewportExtEx()


@pytest.mark.skip
def test_GetViewportOrgEx():
    GetViewportOrgEx()


@pytest.mark.skip
def test_GetWindow():
    GetWindow()


@pytest.mark.skip
def test_GetWindowDC():
    GetWindowDC()


@pytest.mark.skip
def test_GetWindowExtEx():
    GetWindowExtEx()


@pytest.mark.skip
def test_GetWindowLong():
    GetWindowLong()


@pytest.mark.skip
def test_GetWindowOrgEx():
    GetWindowOrgEx()


@pytest.mark.skip
def test_GetWindowPlacement():
    GetWindowPlacement()


@pytest.mark.skip
def test_GetWindowRect():
    GetWindowRect()


@pytest.mark.skip
def test_GetWindowRgn():
    GetWindowRgn()


@pytest.mark.skip
def test_GetWindowRgnBox():
    GetWindowRgnBox()


@pytest.mark.skip
def test_GetWindowText():
    GetWindowText()


@pytest.mark.skip
def test_GetWorldTransform():
    GetWorldTransform()


@pytest.mark.skip
def test_GradientFill():
    GradientFill()


@pytest.mark.skip
def test_HideCaret():
    HideCaret()


@pytest.mark.skip
def test_ImageList_Add():
    ImageList_Add()


@pytest.mark.skip
def test_ImageList_Create():
    ImageList_Create()


@pytest.mark.skip
def test_ImageList_Destroy():
    ImageList_Destroy()


@pytest.mark.skip
def test_ImageList_Draw():
    ImageList_Draw()


@pytest.mark.skip
def test_ImageList_DrawEx():
    ImageList_DrawEx()


@pytest.mark.skip
def test_ImageList_GetIcon():
    ImageList_GetIcon()


@pytest.mark.skip
def test_ImageList_GetImageCount():
    ImageList_GetImageCount()


@pytest.mark.skip
def test_ImageList_LoadBitmap():
    ImageList_LoadBitmap()


@pytest.mark.skip
def test_ImageList_LoadImage():
    ImageList_LoadImage()


@pytest.mark.skip
def test_ImageList_Remove():
    ImageList_Remove()


@pytest.mark.skip
def test_ImageList_Replace():
    ImageList_Replace()


@pytest.mark.skip
def test_ImageList_ReplaceIcon():
    ImageList_ReplaceIcon()


@pytest.mark.skip
def test_ImageList_SetBkColor():
    ImageList_SetBkColor()


@pytest.mark.skip
def test_ImageList_SetOverlayImage():
    ImageList_SetOverlayImage()


@pytest.mark.skip
def test_InitCommonControls():
    InitCommonControls()


@pytest.mark.skip
def test_InitCommonControlsEx():
    InitCommonControlsEx()


@pytest.mark.skip
def test_InsertMenu():
    InsertMenu()


@pytest.mark.skip
def test_InsertMenuItem():
    InsertMenuItem()


@pytest.mark.skip
def test_InvalidateRect():
    InvalidateRect()


@pytest.mark.skip
def test_InvalidateRgn():
    InvalidateRgn()


@pytest.mark.skip
def test_InvertRect():
    InvertRect()


@pytest.mark.skip
def test_InvertRgn():
    InvertRgn()


@pytest.mark.skip
def test_IsChild():
    IsChild()


@pytest.mark.skip
def test_IsIconic():
    IsIconic()


@pytest.mark.skip
def test_IsWindow():
    IsWindow()


@pytest.mark.skip
def test_IsWindowEnabled():
    IsWindowEnabled()


@pytest.mark.skip
def test_IsWindowVisible():
    IsWindowVisible()


@pytest.mark.skip
def test_LOGFONT():
    LOGFONT()


@pytest.mark.skip
def test_LineTo():
    LineTo()


@pytest.mark.skip
def test_ListView_SortItems():
    ListView_SortItems()


@pytest.mark.skip
def test_ListView_SortItemsEx():
    ListView_SortItemsEx()


@pytest.mark.skip
def test_LoadCursor():
    LoadCursor()


@pytest.mark.skip
def test_LoadIcon():
    LoadIcon()


@pytest.mark.skip
def test_LoadImage():
    LoadImage()


@pytest.mark.skip
def test_LoadMenu():
    LoadMenu()


@pytest.mark.skip
def test_MaskBlt():
    MaskBlt()


@pytest.mark.skip
def test_MessageBeep():
    MessageBeep()


@pytest.mark.skip
def test_MessageBox():
    MessageBox()


@pytest.mark.skip
def test_ModifyMenu():
    ModifyMenu()


@pytest.mark.skip
def test_ModifyWorldTransform():
    ModifyWorldTransform()


@pytest.mark.skip
def test_MoveToEx():
    MoveToEx()


@pytest.mark.skip
def test_MoveWindow():
    MoveWindow()


@pytest.mark.skip
def test_OffsetRgn():
    OffsetRgn()


@pytest.mark.skip
def test_PaintDesktop():
    PaintDesktop()


@pytest.mark.skip
def test_PaintRgn():
    PaintRgn()


@pytest.mark.skip
def test_PatBlt():
    PatBlt()


@pytest.mark.skip
def test_PathToRegion():
    PathToRegion()


@pytest.mark.skip
def test_PeekMessage():
    PeekMessage()


@pytest.mark.skip
def test_Pie():
    Pie()


@pytest.mark.skip
def test_PlgBlt():
    PlgBlt()


@pytest.mark.skip
def test_PolyBezier():
    PolyBezier()


@pytest.mark.skip
def test_PolyBezierTo():
    PolyBezierTo()


@pytest.mark.skip
def test_Polygon():
    Polygon()


@pytest.mark.skip
def test_Polyline():
    Polyline()


@pytest.mark.skip
def test_PolylineTo():
    PolylineTo()


@pytest.mark.skip
def test_PostMessage():
    PostMessage()


@pytest.mark.skip
def test_PostQuitMessage():
    PostQuitMessage()


@pytest.mark.skip
def test_PostThreadMessage():
    PostThreadMessage()


@pytest.mark.skip
def test_PtInRect():
    PtInRect()


@pytest.mark.skip
def test_PtInRegion():
    PtInRegion()


@pytest.mark.skip
def test_PumpMessages():
    PumpMessages()


@pytest.mark.skip
def test_PumpWaitingMessages():
    PumpWaitingMessages()


@pytest.mark.skip
def test_PyGetArraySignedLong():
    PyGetArraySignedLong()


@pytest.mark.skip
def test_PyGetBufferAddressAndLen():
    PyGetBufferAddressAndLen()


@pytest.mark.skip
def test_PyGetMemory():
    PyGetMemory()


@pytest.mark.skip
def test_PyGetString():
    PyGetString()


@pytest.mark.skip
def test_PySetMemory():
    PySetMemory()


@pytest.mark.skip
def test_PySetString():
    PySetString()


@pytest.mark.skip
def test_RectInRegion():
    RectInRegion()


@pytest.mark.skip
def test_Rectangle():
    Rectangle()


@pytest.mark.skip
def test_RedrawWindow():
    RedrawWindow()


@pytest.mark.skip
def test_RegisterClass():
    RegisterClass()


@pytest.mark.skip
def test_RegisterDeviceNotification():
    RegisterDeviceNotification()


@pytest.mark.skip
def test_RegisterWindowMessage():
    RegisterWindowMessage()


@pytest.mark.skip
def test_ReleaseCapture():
    ReleaseCapture()


@pytest.mark.skip
def test_ReleaseDC():
    ReleaseDC()


@pytest.mark.skip
def test_RemoveMenu():
    RemoveMenu()


@pytest.mark.skip
def test_ReplyMessage():
    ReplyMessage()


@pytest.mark.skip
def test_RestoreDC():
    RestoreDC()


@pytest.mark.skip
def test_RoundRect():
    RoundRect()


@pytest.mark.skip
def test_SaveDC():
    SaveDC()


@pytest.mark.skip
def test_ScreenToClient():
    ScreenToClient()


@pytest.mark.skip
def test_ScrollWindowEx():
    ScrollWindowEx()


@pytest.mark.skip
def test_SelectObject():
    SelectObject()


@pytest.mark.skip
def test_SendMessage():
    SendMessage()


@pytest.mark.skip
def test_SendMessageTimeout():
    SendMessageTimeout()


@pytest.mark.skip
def test_SetActiveWindow():
    SetActiveWindow()


@pytest.mark.skip
def test_SetArcDirection():
    SetArcDirection()


@pytest.mark.skip
def test_SetBkColor():
    SetBkColor()


@pytest.mark.skip
def test_SetBkMode():
    SetBkMode()


@pytest.mark.skip
def test_SetCapture():
    SetCapture()


@pytest.mark.skip
def test_SetCaretPos():
    SetCaretPos()


@pytest.mark.skip
def test_SetCursor():
    SetCursor()


@pytest.mark.skip
def test_SetDlgItemInt():
    SetDlgItemInt()


@pytest.mark.skip
def test_SetDlgItemText():
    SetDlgItemText()


@pytest.mark.skip
def test_SetDoubleClickTime():
    SetDoubleClickTime()


@pytest.mark.skip
def test_SetFocus():
    SetFocus()


@pytest.mark.skip
def test_SetForegroundWindow():
    SetForegroundWindow()


@pytest.mark.skip
def test_SetGraphicsMode():
    SetGraphicsMode()


@pytest.mark.skip
def test_SetLayeredWindowAttributes():
    SetLayeredWindowAttributes()


@pytest.mark.skip
def test_SetLayout():
    SetLayout()


@pytest.mark.skip
def test_SetMapMode():
    SetMapMode()


@pytest.mark.skip
def test_SetMenu():
    SetMenu()


@pytest.mark.skip
def test_SetMenuDefaultItem():
    SetMenuDefaultItem()


@pytest.mark.skip
def test_SetMenuInfo():
    SetMenuInfo()


@pytest.mark.skip
def test_SetMenuItemBitmaps():
    SetMenuItemBitmaps()


@pytest.mark.skip
def test_SetMenuItemInfo():
    SetMenuItemInfo()


@pytest.mark.skip
def test_SetMiterLimit():
    SetMiterLimit()


@pytest.mark.skip
def test_SetParent():
    SetParent()


@pytest.mark.skip
def test_SetPixel():
    SetPixel()


@pytest.mark.skip
def test_SetPixelV():
    SetPixelV()


@pytest.mark.skip
def test_SetPolyFillMode():
    SetPolyFillMode()


@pytest.mark.skip
def test_SetROP2():
    SetROP2()


@pytest.mark.skip
def test_SetRectRgn():
    SetRectRgn()


@pytest.mark.skip
def test_SetScrollInfo():
    SetScrollInfo()


@pytest.mark.skip
def test_SetStretchBltMode():
    SetStretchBltMode()


@pytest.mark.skip
def test_SetTextAlign():
    SetTextAlign()


@pytest.mark.skip
def test_SetTextCharacterExtra():
    SetTextCharacterExtra()


@pytest.mark.skip
def test_SetTextColor():
    SetTextColor()


@pytest.mark.skip
def test_SetViewportExtEx():
    SetViewportExtEx()


@pytest.mark.skip
def test_SetViewportOrgEx():
    SetViewportOrgEx()


@pytest.mark.skip
def test_SetWindowExtEx():
    SetWindowExtEx()


@pytest.mark.skip
def test_SetWindowLong():
    SetWindowLong()


@pytest.mark.skip
def test_SetWindowOrgEx():
    SetWindowOrgEx()


@pytest.mark.skip
def test_SetWindowPlacement():
    SetWindowPlacement()


@pytest.mark.skip
def test_SetWindowPos():
    SetWindowPos()


@pytest.mark.skip
def test_SetWindowRgn():
    SetWindowRgn()


@pytest.mark.skip
def test_SetWindowText():
    SetWindowText()


@pytest.mark.skip
def test_SetWorldTransform():
    SetWorldTransform()


@pytest.mark.skip
def test_Shell_NotifyIcon():
    Shell_NotifyIcon()


@pytest.mark.skip
def test_ShowCaret():
    ShowCaret()


@pytest.mark.skip
def test_ShowWindow():
    ShowWindow()


@pytest.mark.skip
def test_StretchBlt():
    StretchBlt()


@pytest.mark.skip
def test_StrokeAndFillPath():
    StrokeAndFillPath()


@pytest.mark.skip
def test_StrokePath():
    StrokePath()


@pytest.mark.skip
def test_SystemParametersInfo():
    SystemParametersInfo()


@pytest.mark.skip
def test_TrackPopupMenu():
    TrackPopupMenu()


@pytest.mark.skip
def test_TranslateAccelerator():
    TranslateAccelerator()


@pytest.mark.skip
def test_TranslateMessage():
    TranslateMessage()


@pytest.mark.skip
def test_TransparentBlt():
    TransparentBlt()


@pytest.mark.skip
def test_UnregisterClass():
    UnregisterClass()


@pytest.mark.skip
def test_UnregisterDeviceNotification():
    UnregisterDeviceNotification()


@pytest.mark.skip
def test_UpdateLayeredWindow():
    UpdateLayeredWindow()


@pytest.mark.skip
def test_UpdateWindow():
    UpdateWindow()


@pytest.mark.skip
def test_ValidateRgn():
    ValidateRgn()


@pytest.mark.skip
def test_WaitMessage():
    WaitMessage()


@pytest.mark.skip
def test_WidenPath():
    WidenPath()


@pytest.mark.skip
def test_WindowFromDC():
    WindowFromDC()


@pytest.mark.skip
def test_WindowFromPoint():
    WindowFromPoint()


@pytest.mark.skip
def test_TrackMouseEvent():
    TrackMouseEvent()


@pytest.mark.skip
def test_set_logger():
    set_logger()



import pytest
import pytest
import pytest
import pytest
import pytest
from axcontrol import *
@pytest.mark.xfail
def test_OleCreate():
    OleCreate()     



@pytest.mark.xfail
def test_OleLoadPicture():
    OleLoadPicture()     



@pytest.mark.xfail
def test_OleLoadPicturePath():
    OleLoadPicturePath()     



@pytest.mark.xfail
def test_OleSetContainedObject():
    OleSetContainedObject()     



@pytest.mark.xfail
def test_OleTranslateAccelerator():
    OleTranslateAccelerator()     





import pytest
import pytest
import pytest
from internet import *
@pytest.mark.xfail
def test_CoInternetCreateSecurityManager():
    CoInternetCreateSecurityManager()     



@pytest.mark.xfail
def test_CoInternetIsFeatureEnabled():
    CoInternetIsFeatureEnabled()     



@pytest.mark.xfail
def test_CoInternetSetFeatureEnabled():
    CoInternetSetFeatureEnabled()     





import pytest
import pytest
import pytest
import pytest
import pytest
from perfmon import *
@pytest.mark.xfail
def test_CounterDefinition():
    CounterDefinition()     



@pytest.mark.xfail
def test_LoadPerfCounterTextStrings():
    LoadPerfCounterTextStrings()     



@pytest.mark.xfail
def test_ObjectType():
    ObjectType()     



@pytest.mark.xfail
def test_PerfMonManager():
    PerfMonManager()     



@pytest.mark.xfail
def test_UnloadPerfCounterTextStrings():
    UnloadPerfCounterTextStrings()     





import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest

from win32ts import *


@pytest.mark.xfail
def test_ProcessIdToSessionId():
    ProcessIdToSessionId()


@pytest.mark.xfail
def test_WTSCloseServer():
    WTSCloseServer()


@pytest.mark.xfail
def test_WTSDisconnectSession():
    WTSDisconnectSession()


def test_WTSEnumerateProcesses():
    WTSEnumerateProcesses()


@pytest.mark.xfail
def test_WTSEnumerateServers():
    WTSEnumerateServers()


def test_WTSEnumerateSessions():
    WTSEnumerateSessions()


def test_WTSGetActiveConsoleSessionId():
    WTSGetActiveConsoleSessionId()


@pytest.mark.xfail
def test_WTSLogoffSession():
    WTSLogoffSession()


@pytest.mark.xfail
def test_WTSOpenServer():
    WTSOpenServer()


@pytest.mark.xfail
def test_WTSQuerySessionInformation():
    WTSQuerySessionInformation()


@pytest.mark.xfail
def test_WTSQueryUserConfig():
    WTSQueryUserConfig()


@pytest.mark.xfail
def test_WTSQueryUserToken():
    WTSQueryUserToken()


@pytest.mark.xfail
def test_WTSRegisterSessionNotification():
    WTSRegisterSessionNotification()


@pytest.mark.xfail
def test_WTSSendMessage():
    WTSSendMessage()


@pytest.mark.xfail
def test_WTSSetUserConfig():
    WTSSetUserConfig()


@pytest.mark.xfail
def test_WTSShutdownSystem():
    WTSShutdownSystem()


@pytest.mark.xfail
def test_WTSTerminateProcess():
    WTSTerminateProcess()


@pytest.mark.xfail
def test_WTSUnRegisterSessionNotification():
    WTSUnRegisterSessionNotification()


@pytest.mark.skip
def test_WTSWaitSystemEvent():
    WTSWaitSystemEvent()



"""Test pywin32's error semantics"""
import sys
import unittest
import win32api

import pytest
import pythoncom
import pywintypes
import winerror


class TestBase(unittest.TestCase):
    def _testExceptionIndex(self, exc, index, expected):
        # check the exception itself can be indexed if not py3k
        if sys.version_info < (3,):
            assert exc[index] == expected
        # and that exception.args can is the same.
        assert exc.args[index] == expected


class TestAPISimple(TestBase):
    def _getInvalidHandleException(self):
        try:
            win32api.CloseHandle(1)
        except win32api.error as exc:
            return exc
        self.fail("Didn't get invalid-handle exception.")

    def testSimple(self):
        with pytest.raises(pywintypes.error):
            win32api.CloseHandle(1)

    def testErrnoIndex(self):
        exc = self._getInvalidHandleException()
        self._testExceptionIndex(exc, 0, winerror.ERROR_INVALID_HANDLE)

    def testFuncIndex(self):
        exc = self._getInvalidHandleException()
        self._testExceptionIndex(exc, 1, "CloseHandle")

    def testMessageIndex(self):
        exc = self._getInvalidHandleException()
        expected = win32api.FormatMessage(
            winerror.ERROR_INVALID_HANDLE).rstrip()
        self._testExceptionIndex(exc, 2, expected)

    def testUnpack(self):
        try:
            win32api.CloseHandle(1)
            self.fail("expected exception!")
        except win32api.error as exc:
            assert exc.winerror == winerror.ERROR_INVALID_HANDLE
            assert exc.funcname == "CloseHandle"
            expected_msg = win32api.FormatMessage(
                winerror.ERROR_INVALID_HANDLE).rstrip()
            assert exc.strerror == expected_msg

    def testAsStr(self):
        exc = self._getInvalidHandleException()
        err_msg = win32api.FormatMessage(
            winerror.ERROR_INVALID_HANDLE).rstrip()
        # early on the result actually *was* a tuple - it must always look like
        # one
        err_tuple = (winerror.ERROR_INVALID_HANDLE, 'CloseHandle', err_msg)
        assert str(exc) == str(err_tuple)

    def testAsTuple(self):
        exc = self._getInvalidHandleException()
        err_msg = win32api.FormatMessage(
            winerror.ERROR_INVALID_HANDLE).rstrip()
        # early on the result actually *was* a tuple - it must be able to be
        # one
        err_tuple = (winerror.ERROR_INVALID_HANDLE, 'CloseHandle', err_msg)
        if sys.version_info < (3,):
            assert tuple(exc) == err_tuple
        else:
            assert exc.args == err_tuple

    def testClassName(self):
        exc = self._getInvalidHandleException()
        # The error class has always been named 'error'.  That's not ideal :(
        assert exc.__class__.__name__ == "error"

    def testIdentity(self):
        exc = self._getInvalidHandleException()
        assert exc.__class__ is pywintypes.error

    def testBaseClass(self):
        assert pywintypes.error.__bases__ == (Exception,)

    def testAttributes(self):
        exc = self._getInvalidHandleException()
        err_msg = win32api.FormatMessage(
            winerror.ERROR_INVALID_HANDLE).rstrip()
        assert exc.winerror == winerror.ERROR_INVALID_HANDLE
        assert exc.strerror == err_msg
        assert exc.funcname == 'CloseHandle'

    # some tests for 'insane' args.
    def testStrangeArgsNone(self):
        try:
            raise pywintypes.error()
            self.fail("Expected exception")
        except pywintypes.error as exc:
            assert exc.args == ()
            assert exc.winerror == None
            assert exc.funcname == None
            assert exc.strerror == None

    def testStrangeArgsNotEnough(self):
        try:
            raise pywintypes.error("foo")
            self.fail("Expected exception")
        except pywintypes.error as exc:
            assert exc.args[0] == "foo"
            # 'winerror' always args[0]
            assert exc.winerror == "foo"
            assert exc.funcname == None
            assert exc.strerror == None

    def testStrangeArgsTooMany(self):
        try:
            raise pywintypes.error("foo", "bar", "you", "never", "kn", 0)
            self.fail("Expected exception")
        except pywintypes.error as exc:
            assert exc.args[0] == "foo"
            assert exc.args[-1] == 0
            assert exc.winerror == "foo"
            assert exc.funcname == "bar"
            assert exc.strerror == "you"


class TestCOMSimple(TestBase):
    def _getException(self):
        try:
            pythoncom.StgOpenStorage("foo", None, 0)
        except pythoncom.com_error as exc:
            return exc
        self.fail("Didn't get storage exception.")

    def testIs(self):
        assert pythoncom.com_error is pywintypes.com_error

    def testSimple(self):
        with pytest.raises(
                pythoncom.com_error):
            pythoncom.StgOpenStorage("foo",
            None,
            0)

    def testErrnoIndex(self):
        exc = self._getException()
        self._testExceptionIndex(exc, 0, winerror.STG_E_INVALIDFLAG)

    def testMessageIndex(self):
        exc = self._getException()
        expected = win32api.FormatMessage(winerror.STG_E_INVALIDFLAG).rstrip()
        self._testExceptionIndex(exc, 1, expected)

    def testAsStr(self):
        exc = self._getException()
        err_msg = win32api.FormatMessage(winerror.STG_E_INVALIDFLAG).rstrip()
        # early on the result actually *was* a tuple - it must always look like
        # one
        err_tuple = (winerror.STG_E_INVALIDFLAG, err_msg, None, None)
        assert str(exc) == str(err_tuple)

    def testAsTuple(self):
        exc = self._getException()
        err_msg = win32api.FormatMessage(winerror.STG_E_INVALIDFLAG).rstrip()
        # early on the result actually *was* a tuple - it must be able to be
        # one
        err_tuple = (winerror.STG_E_INVALIDFLAG, err_msg, None, None)
        if sys.version_info < (3,):
            assert tuple(exc) == err_tuple
        else:
            assert exc.args == err_tuple

    def testClassName(self):
        exc = self._getException()
        assert exc.__class__.__name__ == "com_error"

    def testIdentity(self):
        exc = self._getException()
        assert exc.__class__ is pywintypes.com_error

    def testBaseClass(self):
        exc = self._getException()
        assert pywintypes.com_error.__bases__ == (Exception,)

    def testAttributes(self):
        exc = self._getException()
        err_msg = win32api.FormatMessage(winerror.STG_E_INVALIDFLAG).rstrip()
        assert exc.hresult == winerror.STG_E_INVALIDFLAG
        assert exc.strerror == err_msg
        assert exc.argerror == None
        assert exc.excepinfo == None

    def testStrangeArgsNone(self):
        try:
            raise pywintypes.com_error()
            self.fail("Expected exception")
        except pywintypes.com_error as exc:
            assert exc.args == ()
            assert exc.hresult == None
            assert exc.strerror == None
            assert exc.argerror == None
            assert exc.excepinfo == None

    def testStrangeArgsNotEnough(self):
        try:
            raise pywintypes.com_error("foo")
            self.fail("Expected exception")
        except pywintypes.com_error as exc:
            assert exc.args[0] == "foo"
            assert exc.hresult == "foo"
            assert exc.strerror == None
            assert exc.excepinfo == None
            assert exc.argerror == None

    def testStrangeArgsTooMany(self):
        try:
            raise pywintypes.com_error("foo", "bar", "you", "never", "kn", 0)
            self.fail("Expected exception")
        except pywintypes.com_error as exc:
            assert exc.args[0] == "foo"
            assert exc.args[-1] == 0
            assert exc.hresult == "foo"
            assert exc.strerror == "bar"
            assert exc.excepinfo == "you"
            assert exc.argerror == "never"


if __name__ == '__main__':
    unittest.main()



# Tests for the win32security module.
import unittest
import win32api
import win32security

import ntsecuritycon
import pytest
import win32con
import winerror
from pywin32_testutil import TestSkipped, ob2memory


class SecurityTests(unittest.TestCase):
    def setUp(self):
        self.pwr_sid = win32security.LookupAccountName('', 'Power Users')[0]
        self.admin_sid = win32security.LookupAccountName('',
                                                         'Administrator')[0]

    def tearDown(self):
        pass

    def testEqual(self):
        assert win32security.LookupAccountName(
            '', 'Administrator')[0] == win32security.LookupAccountName(
                '', 'Administrator')[0]

    def testNESID(self):
        assert self.pwr_sid == self.pwr_sid
        assert self.pwr_sid != self.admin_sid

    def testNEOther(self):
        assert self.pwr_sid is not None
        assert None != self.pwr_sid
        assert not (self.pwr_sid is None)
        assert not (None == self.pwr_sid)
        assert None != self.pwr_sid

    def testSIDInDict(self):
        d = dict(foo=self.pwr_sid)
        assert d['foo'] == self.pwr_sid

    def testBuffer(self):
        assert ob2memory(
            win32security.LookupAccountName('', 'Administrator')[
                0]) == ob2memory(
                    win32security.LookupAccountName('', 'Administrator')[0])

    def testMemory(self):
        pwr_sid = self.pwr_sid
        admin_sid = self.admin_sid
        sd1 = win32security.SECURITY_DESCRIPTOR()
        sd2 = win32security.SECURITY_DESCRIPTOR()
        sd3 = win32security.SECURITY_DESCRIPTOR()
        dacl = win32security.ACL()
        dacl.AddAccessAllowedAce(win32security.ACL_REVISION,
                                 win32con.GENERIC_READ, pwr_sid)
        dacl.AddAccessAllowedAce(win32security.ACL_REVISION,
                                 win32con.GENERIC_ALL, admin_sid)
        sd4 = win32security.SECURITY_DESCRIPTOR()
        sacl = win32security.ACL()
        sacl.AddAuditAccessAce(win32security.ACL_REVISION, win32con.DELETE,
                               admin_sid, 1, 1)
        sacl.AddAuditAccessAce(win32security.ACL_REVISION,
                               win32con.GENERIC_ALL, pwr_sid, 1, 1)
        for x in range(0, 200000):
            sd1.SetSecurityDescriptorOwner(admin_sid, 0)
            sd2.SetSecurityDescriptorGroup(pwr_sid, 0)
            sd3.SetSecurityDescriptorDacl(1, dacl, 0)
            sd4.SetSecurityDescriptorSacl(1, sacl, 0)


class DomainTests(unittest.TestCase):
    def setUp(self):
        self.ds_handle = None
        try:
            # saving the handle means the other test itself should bind faster.
            self.ds_handle = win32security.DsBind()
        except win32security.error as exc:
            if exc.winerror != winerror.ERROR_NO_SUCH_DOMAIN:
                raise
            raise TestSkipped(exc)

    def tearDown(self):
        if self.ds_handle is not None:
            self.ds_handle.close()


class TestDS(DomainTests):
    @pytest.mark.xfail
    def testDsGetDcName(self):
        # Not sure what we can actually test here!  At least calling it
        # does something :)
        win32security.DsGetDcName()

    @pytest.mark.xfail
    def testDsListServerInfo(self):
        # again, not checking much, just exercising the code.
        h = win32security.DsBind()
        for (status, ignore, site) in win32security.DsListSites(h):
            for (status, ignore, server) in win32security.DsListServersInSite(
                    h, site):
                info = win32security.DsListInfoForServer(h, server)
            for (status, ignore, domain) in win32security.DsListDomainsInSite(
                    h, site):
                pass

    @pytest.mark.xfail
    def testDsCrackNames(self):
        h = win32security.DsBind()
        fmt_offered = ntsecuritycon.DS_FQDN_1779_NAME
        name = win32api.GetUserNameEx(fmt_offered)
        result = win32security.DsCrackNames(h, 0, fmt_offered, fmt_offered,
                                            (name, ))
        assert name == result[0][2]

    @pytest.mark.xfail
    def testDsCrackNamesSyntax(self):
        # Do a syntax check only - that allows us to avoid binding.
        # But must use DS_CANONICAL_NAME (or _EX)
        expected = win32api.GetUserNameEx(win32api.NameCanonical)
        fmt_offered = ntsecuritycon.DS_FQDN_1779_NAME
        name = win32api.GetUserNameEx(fmt_offered)
        result = win32security.DsCrackNames(
            None, ntsecuritycon.DS_NAME_FLAG_SYNTACTICAL_ONLY, fmt_offered,
            ntsecuritycon.DS_CANONICAL_NAME, (name, ))
        assert expected == result[0][2]


class TestTranslate(DomainTests):
    def _testTranslate(self, fmt_from, fmt_to):
        name = win32api.GetUserNameEx(fmt_from)
        expected = win32api.GetUserNameEx(fmt_to)
        got = win32security.TranslateName(name, fmt_from, fmt_to)
        assert got == expected

    @pytest.mark.xfail
    def testTranslate1(self):
        self._testTranslate(win32api.NameFullyQualifiedDN,
                            win32api.NameSamCompatible)

    @pytest.mark.xfail
    def testTranslate2(self):
        self._testTranslate(win32api.NameSamCompatible,
                            win32api.NameFullyQualifiedDN)

    @pytest.mark.xfail
    def testTranslate3(self):
        self._testTranslate(win32api.NameFullyQualifiedDN,
                            win32api.NameUniqueId)

    @pytest.mark.xfail
    def testTranslate4(self):
        self._testTranslate(win32api.NameUniqueId,
                            win32api.NameFullyQualifiedDN)


# if __name__ == '__main__':
#     testmain()



import os
import sys

print('WARNING: This script does not support spaces in the path!')
target_dir = sys.argv[1]
for file in os.listdir(target_dir):
    if file.endswith('.whl'):
        cmd = 'pip install {}'.format(os.path.join(target_dir, file))
        print(cmd)
        os.system(cmd)


import pytest

from shell import *


@pytest.mark.xfail
def test_AddressAsPIDL():
    AddressAsPIDL()


def test_AssocCreate():
    AssocCreate()


@pytest.mark.xfail
def test_AssocCreateForClasses():
    AssocCreateForClasses()


@pytest.mark.xfail
def test_CIDAAsString():
    CIDAAsString()


@pytest.mark.xfail
def test_DragQueryFile():
    DragQueryFile()


@pytest.mark.xfail
def test_DragQueryFileW():
    DragQueryFileW()


@pytest.mark.xfail
def test_DragQueryPoint():
    DragQueryPoint()


@pytest.mark.xfail
def test_FILEGROUPDESCRIPTORAsString():
    FILEGROUPDESCRIPTORAsString()


def test_IsUserAnAdmin():
    IsUserAnAdmin()


@pytest.mark.xfail
def test_PIDLAsString():
    PIDLAsString()


@pytest.mark.xfail
def test_SHAddToRecentDocs():
    SHAddToRecentDocs()


@pytest.mark.skip
def test_SHBrowseForFolder():
    SHBrowseForFolder()


@pytest.mark.xfail
def test_SHChangeNotify():
    SHChangeNotify()


@pytest.mark.xfail
def test_SHChangeNotify():
    SHChangeNotify()


@pytest.mark.xfail
def test_SHChangeNotifyDeregister():
    SHChangeNotifyDeregister()


@pytest.mark.xfail
def test_SHChangeNotifyRegister():
    SHChangeNotifyRegister()


@pytest.mark.xfail
def test_SHCreateDataObject():
    SHCreateDataObject()


@pytest.mark.xfail
def test_SHCreateDefaultContextMenu():
    SHCreateDefaultContextMenu()


def test_SHCreateDefaultExtractIcon():
    SHCreateDefaultExtractIcon()


@pytest.mark.xfail
def test_SHCreateItemFromIDList():
    SHCreateItemFromIDList()


@pytest.mark.xfail
def test_SHCreateItemFromParsingName():
    SHCreateItemFromParsingName()


@pytest.mark.xfail
def test_SHCreateItemFromRelativeName():
    SHCreateItemFromRelativeName()


@pytest.mark.xfail
def test_SHCreateItemInKnownFolder():
    SHCreateItemInKnownFolder()


@pytest.mark.xfail
def test_SHCreateItemWithParent():
    SHCreateItemWithParent()


@pytest.mark.xfail
def test_SHCreateShellFolderView():
    SHCreateShellFolderView()


@pytest.mark.xfail
def test_SHCreateShellItemArray():
    SHCreateShellItemArray()


@pytest.mark.xfail
def test_SHCreateShellItemArrayFromDataObject():
    SHCreateShellItemArrayFromDataObject()


@pytest.mark.xfail
def test_SHCreateShellItemArrayFromIDLists():
    SHCreateShellItemArrayFromIDLists()


@pytest.mark.xfail
def test_SHCreateShellItemArrayFromIDLists():
    SHCreateShellItemArrayFromIDLists()


@pytest.mark.xfail
def test_SHEmptyRecycleBin():
    SHEmptyRecycleBin()


@pytest.mark.xfail
def test_SHFileOperation():
    SHFileOperation()


def test_SHGetDesktopFolder():
    SHGetDesktopFolder()


@pytest.mark.xfail
def test_SHGetFileInfo():
    SHGetFileInfo()


@pytest.mark.xfail
def test_SHGetFolderLocation():
    SHGetFolderLocation()


@pytest.mark.xfail
def test_SHGetFolderPath():
    SHGetFolderPath()


@pytest.mark.xfail
def test_SHGetIDListFromObject():
    SHGetIDListFromObject()


@pytest.mark.xfail
def test_SHGetInstanceExplorer():
    SHGetInstanceExplorer()


@pytest.mark.xfail
def test_SHGetNameFromIDList():
    SHGetNameFromIDList()


@pytest.mark.xfail
def test_SHGetPathFromIDList():
    SHGetPathFromIDList()


@pytest.mark.xfail
def test_SHGetPathFromIDListW():
    SHGetPathFromIDListW()


def test_SHGetSettings():
    SHGetSettings()


@pytest.mark.xfail
def test_SHGetSpecialFolderLocation():
    SHGetSpecialFolderLocation()


@pytest.mark.xfail
def test_SHGetSpecialFolderPath():
    SHGetSpecialFolderPath()


@pytest.mark.xfail
def test_SHGetViewStatePropertyBag():
    SHGetViewStatePropertyBag()


@pytest.mark.xfail
def test_SHILCreateFromPath():
    SHILCreateFromPath()


def test_SHQueryRecycleBin():
    SHQueryRecycleBin()


@pytest.mark.xfail
def test_SHSetFolderPath():
    SHSetFolderPath()


@pytest.mark.xfail
def test_SHUpdateImage():
    SHUpdateImage()


def test_ShellExecuteEx():
    ShellExecuteEx()


@pytest.mark.xfail
def test_StringAsCIDA():
    StringAsCIDA()


@pytest.mark.xfail
def test_StringAsFILEGROUPDESCRIPTOR():
    StringAsFILEGROUPDESCRIPTOR()


@pytest.mark.xfail
def test_StringAsPIDL():
    StringAsPIDL()



import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32net import *
@pytest.mark.xfail
def test_NetFileClose():
    NetFileClose()     



@pytest.mark.xfail
def test_NetFileEnum():
    NetFileEnum()     



@pytest.mark.xfail
def test_NetFileGetInfo():
    NetFileGetInfo()     



@pytest.mark.xfail
def test_NetGetAnyDCName():
    NetGetAnyDCName()     



@pytest.mark.xfail
def test_NetGetDCName():
    NetGetDCName()     



def test_NetGetJoinInformation():
    NetGetJoinInformation()     



@pytest.mark.xfail
def test_NetGroupAdd():
    NetGroupAdd()     



@pytest.mark.xfail
def test_NetGroupAdd():
    NetGroupAdd()     



@pytest.mark.xfail
def test_NetGroupAddUser():
    NetGroupAddUser()     



@pytest.mark.xfail
def test_NetGroupDel():
    NetGroupDel()     



@pytest.mark.xfail
def test_NetGroupDel():
    NetGroupDel()     



@pytest.mark.xfail
def test_NetGroupDelUser():
    NetGroupDelUser()     



@pytest.mark.xfail
def test_NetGroupEnum():
    NetGroupEnum()     



@pytest.mark.xfail
def test_NetGroupEnum():
    NetGroupEnum()     



@pytest.mark.xfail
def test_NetGroupGetInfo():
    NetGroupGetInfo()     



@pytest.mark.xfail
def test_NetGroupGetInfo():
    NetGroupGetInfo()     



@pytest.mark.xfail
def test_NetGroupGetUsers():
    NetGroupGetUsers()     



@pytest.mark.xfail
def test_NetGroupSetInfo():
    NetGroupSetInfo()     



@pytest.mark.xfail
def test_NetGroupSetInfo():
    NetGroupSetInfo()     



@pytest.mark.xfail
def test_NetGroupSetUsers():
    NetGroupSetUsers()     



@pytest.mark.xfail
def test_NetLocalGroupAddMembers():
    NetLocalGroupAddMembers()     



@pytest.mark.xfail
def test_NetLocalGroupDelMembers():
    NetLocalGroupDelMembers()     



@pytest.mark.xfail
def test_NetLocalGroupGetMembers():
    NetLocalGroupGetMembers()     



@pytest.mark.xfail
def test_NetLocalGroupSetMembers():
    NetLocalGroupSetMembers()     



@pytest.mark.xfail
def test_NetMessageBufferSend():
    NetMessageBufferSend()     



@pytest.mark.xfail
def test_NetMessageNameAdd():
    NetMessageNameAdd()     



@pytest.mark.xfail
def test_NetMessageNameDel():
    NetMessageNameDel()     



@pytest.mark.xfail
def test_NetMessageNameEnum():
    NetMessageNameEnum()     



@pytest.mark.xfail
def test_NetServerComputerNameAdd():
    NetServerComputerNameAdd()     



@pytest.mark.xfail
def test_NetServerComputerNameDel():
    NetServerComputerNameDel()     



@pytest.mark.xfail
def test_NetServerDiskEnum():
    NetServerDiskEnum()     



@pytest.mark.xfail
def test_NetServerEnum():
    NetServerEnum()     



@pytest.mark.xfail
def test_NetServerGetInfo():
    NetServerGetInfo()     



@pytest.mark.xfail
def test_NetServerSetInfo():
    NetServerSetInfo()     



@pytest.mark.xfail
def test_NetSessionDel():
    NetSessionDel()     



@pytest.mark.xfail
def test_NetSessionEnum():
    NetSessionEnum()     



@pytest.mark.xfail
def test_NetSessionGetInfo():
    NetSessionGetInfo()     



@pytest.mark.xfail
def test_NetShareAdd():
    NetShareAdd()     



@pytest.mark.xfail
def test_NetShareCheck():
    NetShareCheck()     



@pytest.mark.xfail
def test_NetShareDel():
    NetShareDel()     



@pytest.mark.xfail
def test_NetShareEnum():
    NetShareEnum()     



@pytest.mark.xfail
def test_NetShareGetInfo():
    NetShareGetInfo()     



@pytest.mark.xfail
def test_NetShareSetInfo():
    NetShareSetInfo()     



@pytest.mark.xfail
def test_NetStatisticsGet():
    NetStatisticsGet()     



@pytest.mark.xfail
def test_NetUseAdd():
    NetUseAdd()     



@pytest.mark.xfail
def test_NetUseDel():
    NetUseDel()     



@pytest.mark.xfail
def test_NetUseEnum():
    NetUseEnum()     



@pytest.mark.xfail
def test_NetUseGetInfo():
    NetUseGetInfo()     



@pytest.mark.xfail
def test_NetUserAdd():
    NetUserAdd()     



@pytest.mark.xfail
def test_NetUserChangePassword():
    NetUserChangePassword()     



@pytest.mark.xfail
def test_NetUserDel():
    NetUserDel()     



@pytest.mark.xfail
def test_NetUserEnum():
    NetUserEnum()     



@pytest.mark.xfail
def test_NetUserGetGroups():
    NetUserGetGroups()     



@pytest.mark.xfail
def test_NetUserGetInfo():
    NetUserGetInfo()     



@pytest.mark.xfail
def test_NetUserGetLocalGroups():
    NetUserGetLocalGroups()     



@pytest.mark.xfail
def test_NetUserModalsGet():
    NetUserModalsGet()     



@pytest.mark.xfail
def test_NetUserModalsSet():
    NetUserModalsSet()     



@pytest.mark.xfail
def test_NetUserSetInfo():
    NetUserSetInfo()     



@pytest.mark.xfail
def test_NetValidateName():
    NetValidateName()     



@pytest.mark.xfail
def test_NetValidatePasswordPolicy():
    NetValidatePasswordPolicy()     



@pytest.mark.xfail
def test_NetWkstaGetInfo():
    NetWkstaGetInfo()     



@pytest.mark.xfail
def test_NetWkstaSetInfo():
    NetWkstaSetInfo()     



@pytest.mark.xfail
def test_NetWkstaTransportAdd():
    NetWkstaTransportAdd()     



@pytest.mark.xfail
def test_NetWkstaTransportDel():
    NetWkstaTransportDel()     



@pytest.mark.xfail
def test_NetWkstaTransportEnum():
    NetWkstaTransportEnum()     



@pytest.mark.xfail
def test_NetWkstaUserEnum():
    NetWkstaUserEnum()     





from exchange import *
def test_HrCreateDirEntryIdEx():
    HrCreateDirEntryIdEx()     



def test_HrCreateProfileName():
    HrCreateProfileName()     



def test_HrFindExchangeGlobalAddressList():
    HrFindExchangeGlobalAddressList()     



def test_HrGetExchangeStatus():
    HrGetExchangeStatus()     



def test_HrGetMailboxDN():
    HrGetMailboxDN()     



def test_HrGetServerDN():
    HrGetServerDN()     



def test_HrMAPIFindDefaultMsgStore():
    HrMAPIFindDefaultMsgStore()     



def test_HrMAPIFindFolder():
    HrMAPIFindFolder()     



def test_HrMAPIFindFolderEx():
    HrMAPIFindFolderEx()     



def test_HrMAPIFindIPMSubtree():
    HrMAPIFindIPMSubtree()     



def test_HrMAPIFindInbox():
    HrMAPIFindInbox()     



def test_HrMAPIFindStore():
    HrMAPIFindStore()     



def test_HrMAPIFindSubfolderEx():
    HrMAPIFindSubfolderEx()     



def test_HrMAPIOpenFolderEx():
    HrMAPIOpenFolderEx()     



def test_HrMAPISetPropBoolean():
    HrMAPISetPropBoolean()     



def test_HrMAPISetPropLong():
    HrMAPISetPropLong()     



def test_HrMailboxLogoff():
    HrMailboxLogoff()     



def test_HrMailboxLogon():
    HrMailboxLogon()     



def test_HrOpenExchangePrivateStore():
    HrOpenExchangePrivateStore()     



def test_HrOpenExchangePublicFolders():
    HrOpenExchangePublicFolders()     



def test_HrOpenExchangePublicStore():
    HrOpenExchangePublicStore()     



def test_HrOpenSessionObject():
    HrOpenSessionObject()     



def test_HrOpenSiteContainer():
    HrOpenSiteContainer()     



def test_HrOpenSiteContainerAddressing():
    HrOpenSiteContainerAddressing()     





import os
import shutil
import distutils.util

from distutils import log
from distutils.dep_util import newer_group
from contextlib import suppress
from setuptools.command.build_ext import build_ext
from win32.distutils.util import generate_libs

# Special definitions for SWIG.
swig_interface_parents = {
    # source file base,     'base class' for generated COM support
    'mapi': None,  # not a class, but module
    'PyIMailUser': 'IMAPIContainer',
    'PyIABContainer': 'IMAPIContainer',
    'PyIAddrBook': 'IMAPIProp',
    'PyIAttach': 'IMAPIProp',
    'PyIDistList': 'IMAPIContainer',
    'PyIMailUser': 'IMAPIContainer',
    'PyIMAPIContainer': 'IMAPIProp',
    'PyIMAPIFolder': 'IMAPIContainer',
    'PyIMAPIProp': '',  # '' == default base
    'PyIMAPISession': '',
    'PyIMAPIStatus': 'IMAPIProp',
    'PyIMAPITable': '',
    'PyIMessage': 'IMAPIProp',
    'PyIMsgServiceAdmin': '',
    'PyIMsgStore': 'IMAPIProp',
    'PyIProfAdmin': '',
    'PyIProfSect': 'IMAPIProp',
    'PyIConverterSession': '',
    # exchange and exchdapi
    'exchange': None,
    'exchdapi': None,
    'PyIExchangeManageStore': '',
    # ADSI
    'adsi': None,  # module
    'PyIADsContainer': 'IDispatch',
    'PyIADsDeleteOps': 'IDispatch',
    'PyIADsUser': 'IADs',
    'PyIDirectoryObject': '',
    'PyIDirectorySearch': '',
    'PyIDsObjectPicker': '',
    'PyIADs': 'IDispatch',
}

# .i files that are #included, and hence are not part of the build.  Our .dsp
# parser isn't smart enough to differentiate these.
swig_include_files = [
    'mapilib',
    'adsilib',
]


class win32_build_ext(build_ext):
    def finalize_options(self):
        build_ext.finalize_options(self)
        self.windows_h_version = None
        self.excluded_extensions = []  # list of (ext, why)
        self.swig_cpp = True  # hrm - deprecated - should use swig_opts=-c++??
        if not hasattr(self, 'plat_name'):
            # Old Python version that doesn't support cross-compile
            self.plat_name = distutils.util.get_platform()

        for ext in self.extensions:
            ext.library_dirs += [
                os.path.join(self.build_temp, d)
                for d in ext.build_temp_library_dirs
            ]

        self.generated_files = []
        self.library_dirs += [self.build_temp]

    def run(self):
        build_ext.run(self)

    def build_extensions(self):
        # First, sanity-check the 'extensions' list
        self.check_extensions_list(self.extensions)
        self.found_libraries = {}

        libs = set()
        # Generate all external modules first
        for ext in self.extensions:
            libs.update(ext.external_modules)

        os.makedirs(self.build_temp, exist_ok=True)
        for lib in generate_libs(list(libs), self.plat_name):
            with suppress(FileNotFoundError):
                os.remove(os.path.join(self.build_temp, os.path.basename(lib)))

            try:
                shutil.move(lib, self.build_temp)
            except OSError:
                shutil.copy(lib, self.build_temp)

        if not hasattr(self.compiler, 'initialized'):
            # 2.3 and earlier initialized at construction
            self.compiler.initialized = True
        else:
            if not self.compiler.initialized:
                self.compiler.initialize()

        try:
            for ext in self.extensions:
                self.build_extension(ext)

        finally:
            for generated_file in self.generated_files:
                target = os.path.join(self.build_temp, generated_file)
                with suppress(OSError):
                    os.makedirs(os.path.dirname(target))
                with suppress(OSError):
                    shutil.move(generated_file, target)

            self.generated_files = []

    def find_swig(self):
        if 'SWIG' in os.environ:
            swig = os.environ['SWIG']
        else:
            # We know where our swig is
            swig = os.path.abspath(os.path.join('swig', 'swig.exe'))
        lib = os.path.join(os.path.dirname(swig), 'swig_lib')
        os.environ['SWIG_LIB'] = lib
        return swig

    def swig_sources(self, sources, extension):
        new_sources = []
        swig_sources = []
        swig_targets = {}
        # XXX this drops generated C/C++ files into the source tree, which
        # is fine for developers who want to distribute the generated
        # source -- but there should be an option to put SWIG output in
        # the temp dir.
        # Adding py3k to the mix means we *really* need to move to generating
        # to the temp dir...
        target_ext = '.cpp'
        for source in sources:
            (base, sext) = os.path.splitext(source)
            if sext == '.i':  # SWIG interface file
                if os.path.split(base)[1] in swig_include_files:
                    continue
                swig_sources.append(source)
                # Patch up the filenames for various special cases...
                if os.path.basename(base) in swig_interface_parents:
                    swig_targets[source] = base + target_ext
                else:
                    new_target = '%s_swig%s' % (base, target_ext)
                    new_sources.append(new_target)
                    swig_targets[source] = new_target
            else:
                new_sources.append(source)

        if not swig_sources:
            return new_sources

        swig = self.find_swig()
        for source in swig_sources:
            swig_cmd = [swig, '-python', '-c++']
            swig_cmd.append(
                '-dnone', )  # we never use the .doc files.
            swig_cmd.extend(extension.extra_swig_commands)

            if distutils.util.get_platform() == 'win-amd64':
                swig_cmd.append('-DSWIG_PY64BIT')
            else:
                swig_cmd.append('-DSWIG_PY32BIT')
            target = swig_targets[source]
            with suppress(KeyError):
                interface_parent = swig_interface_parents[os.path.basename(
                    os.path.splitext(source)[0])]

                # Using win32 extensions to SWIG for generating COM classes.
                if interface_parent is not None:
                    # generating a class, not a module.
                    swig_cmd.append('-pythoncom')
                    if interface_parent:
                        # A class deriving from other than the default
                        swig_cmd.extend(
                            ['-com_interface_parent', interface_parent])

            # This 'newer' check helps python 2.2 builds, which otherwise
            # *always* regenerate the .cpp files, meaning every future
            # build for any platform sees these as dirty.
            # This could probably go once we generate .cpp into the temp dir.
            fqsource = os.path.abspath(source)
            fqtarget = os.path.abspath(target)
            rebuild = self.force or (extension and newer_group(
                extension.swig_deps + [fqsource], fqtarget))
            log.debug('should swig %s->%s=%s', source, target, rebuild)
            new_sources += [target]
            self.generated_files += [
                target, '{}.h'.format(os.path.splitext(target)[0])
            ]
            if rebuild:
                swig_cmd.extend(['-o', fqtarget, fqsource])
                log.info('swigging %s to %s', source, target)
                out_dir = os.path.dirname(source)
                cwd = os.getcwd()
                os.chdir(out_dir)
                try:
                    self.spawn(swig_cmd)
                finally:
                    os.chdir(cwd)
            else:
                log.info('skipping swig of %s', source)

        return list(set(new_sources))



import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32job import *
@pytest.mark.xfail
def test_AssignProcessToJobObject():
    AssignProcessToJobObject()     



@pytest.mark.xfail
def test_CreateJobObject():
    CreateJobObject()     



@pytest.mark.xfail
def test_IsProcessInJob():
    IsProcessInJob()     



@pytest.mark.xfail
def test_OpenJobObject():
    OpenJobObject()     



@pytest.mark.xfail
def test_QueryInformationJobObject():
    QueryInformationJobObject()     



@pytest.mark.xfail
def test_SetInformationJobObject():
    SetInformationJobObject()     



@pytest.mark.xfail
def test_TerminateJobObject():
    TerminateJobObject()     



@pytest.mark.xfail
def test_UserHandleGrantAccess():
    UserHandleGrantAccess()     





import datetime
import operator
import sys
import time
import unittest

import pytest
import pywintypes
from pywin32_testutil import str2bytes, ob2memory


class TestCase(unittest.TestCase):
    def testPyTimeFormat(self):
        struct_current = time.localtime()
        pytime_current = pywintypes.Time(struct_current)
        # try and test all the standard parts of the format
        # Note we used to include '%Z' testing, but that was pretty useless as
        # it always returned the local timezone.
        format_strings = "%a %A %b %B %c %d %H %I %j %m %M %p %S %U %w %W %x %X %y %Y"
        for fmt in format_strings.split():
            v1 = pytime_current.Format(fmt)
            v2 = time.strftime(fmt, struct_current)
            assert v1 == v2, "format %s failed - %r != %r" % \
                             (fmt, v1, v2)

    @pytest.mark.xfail
    def testPyTimePrint(self):
        # This used to crash with an invalid, or too early time.
        # We don't really want to check that it does cause a ValueError
        # (as hopefully this wont be true forever).  So either working, or
        # ValueError is OK.
        try:
            t = pywintypes.Time(-2)
            t.Format()
        except ValueError:
            return

    @pytest.mark.xfail
    def testTimeInDict(self):
        d = {}
        d['t1'] = pywintypes.Time(1)
        assert d['t1'] == pywintypes.Time(1)

    @pytest.mark.xfail
    def testPyTimeCompare(self):
        t1 = pywintypes.Time(100)
        t1_2 = pywintypes.Time(100)
        t2 = pywintypes.Time(101)

        assert t1 == t1_2
        assert t1 <= t1_2
        assert t1_2 >= t1

        assert t1 != t2
        assert t1 < t2
        assert t2 > t1

    @pytest.mark.xfail
    def testPyTimeCompareOther(self):
        t1 = pywintypes.Time(100)
        t2 = None
        assert t1 != t2

    def testTimeTuple(self):
        now = datetime.datetime.now()  # has usec...
        # timetuple() lost usec - pt must be <=...
        pt = pywintypes.Time(now.timetuple())
        # *sob* - only if we have a datetime object can we compare like this.
        if isinstance(pt, datetime.datetime):
            assert pt <= now

    @pytest.mark.xfail
    def testTimeTuplems(self):
        now = datetime.datetime.now()  # has usec...
        tt = now.timetuple() + (now.microsecond // 1000,)
        pt = pywintypes.Time(tt)
        # we can't compare if using the old type, as it loses all sub-second
        # res.
        if isinstance(pt, datetime.datetime):
            assert now == pt

    def testPyTimeFromTime(self):
        t1 = pywintypes.Time(time.time())
        assert pywintypes.Time(t1) is t1

    def testGUID(self):
        s = "{00020400-0000-0000-C000-000000000046}"
        iid = pywintypes.IID(s)
        iid2 = pywintypes.IID(ob2memory(iid), True)
        assert iid == iid2
        with pytest.raises(
                ValueError):
            pywintypes.IID(str2bytes('00'),
            True)  # too short
        with pytest.raises(TypeError):
            pywintypes.IID(0, True)  # no buffer

    def testGUIDRichCmp(self):
        s = "{00020400-0000-0000-C000-000000000046}"
        iid = pywintypes.IID(s)
        assert not (s is None)
        assert not (None == s)
        assert s is not None
        assert None != s
        if sys.version_info > (3, 0):
            with pytest.raises(TypeError):
                operator.gt(None, s)
            with pytest.raises(TypeError):
                operator.gt(s, None)
            with pytest.raises(TypeError):
                operator.lt(None, s)
            with pytest.raises(TypeError):
                operator.lt(s, None)

    def testGUIDInDict(self):
        s = "{00020400-0000-0000-C000-000000000046}"
        iid = pywintypes.IID(s)
        d = dict(item=iid)
        assert d['item'] == iid


if __name__ == '__main__':
    unittest.main()



import requests
import zipfile
import os
import shutil

from io import BytesIO

URL = 'http://sonarqube.com/static/cpp/build-wrapper-win-x86.zip'
DIR = 'C:\\ProgramData\\chocolatey\\bin'

request = requests.get(URL)
zip_file = zipfile.ZipFile(BytesIO(request.content))

for member in zip_file.namelist():
    filename = os.path.basename(member)
    # skip directories
    if not filename:
        continue

    # copy file (taken from zipfile's extract)
    source = zip_file.open(member)
    target = open(os.path.join(DIR, filename), "wb")
    with source, target:
        shutil.copyfileobj(source, target)



import os
import time
import win32api
import win32ui

import pythoncom
import pywintypes
import win32com
import win32com.client
import win32com.client.dynamic
import win32com.server.util
from pywin32_testutil import str2bytes
from win32com import storagecon
from win32com.axcontrol import axcontrol
from win32com.test.util import CheckClean

S_OK = 0

import datetime

if issubclass(pywintypes.TimeType, datetime.datetime):
    import win32timezone

    now = win32timezone.now()
else:
    now = pywintypes.Time(time.time())


class LockBytes:
    _public_methods_ = [
        'ReadAt',
        'WriteAt',
        'Flush',
        'SetSize',
        'LockRegion',
        'UnlockRegion',
        'Stat']
    _com_interfaces_ = [pythoncom.IID_ILockBytes]

    def __init__(self, data=""):
        self.data = str2bytes(data)
        self.ctime = now
        self.mtime = now
        self.atime = now

    def ReadAt(self, offset, cb):
        print("ReadAt")
        result = self.data[offset:offset + cb]
        return result

    def WriteAt(self, offset, data):
        print("WriteAt " + str(offset))
        print("len " + str(len(data)))
        print("data:")
        # print data
        if len(self.data) >= offset:
            newdata = self.data[0:offset] + data
        print(len(newdata))
        if len(self.data) >= offset + len(data):
            newdata = newdata + self.data[offset + len(data):]
        print(len(newdata))
        self.data = newdata
        return len(data)

    def Flush(self, whatsthis=0):
        print("Flush" + str(whatsthis))
        fname = os.path.join(win32api.GetTempPath(), "persist.doc")
        open(fname, "wb").write(self.data)
        return S_OK

    def SetSize(self, size):
        print("Set Size" + str(size))
        if size > len(self.data):
            self.data = self.data + str2bytes("\000" * (size - len(self.data)))
        else:
            self.data = self.data[0:size]
        return S_OK

    def LockRegion(self, offset, size, locktype):
        print("LockRegion")

    def UnlockRegion(self, offset, size, locktype):
        print("UnlockRegion")

    def Stat(self, statflag):
        print("returning Stat " + str(statflag))
        return (
            "PyMemBytes",
            storagecon.STGTY_LOCKBYTES,
            len(self.data),
            self.mtime,
            self.ctime,
            self.atime,
            storagecon.STGM_DIRECT | storagecon.STGM_READWRITE | storagecon.STGM_CREATE,
            storagecon.STGM_SHARE_EXCLUSIVE,
            "{00020905-0000-0000-C000-000000000046}",
            0,  # statebits ?
            0
        )


class OleClientSite:
    _public_methods_ = [
        'SaveObject',
        'GetMoniker',
        'GetContainer',
        'ShowObject',
        'OnShowWindow',
        'RequestNewObjectLayout']
    _com_interfaces_ = [axcontrol.IID_IOleClientSite]

    def __init__(self, data=""):
        self.IPersistStorage = None
        self.IStorage = None

    def SetIPersistStorage(self, IPersistStorage):
        self.IPersistStorage = IPersistStorage

    def SetIStorage(self, IStorage):
        self.IStorage = IStorage

    def SaveObject(self):
        print("SaveObject")
        if self.IPersistStorage is not None and self.IStorage is not None:
            self.IPersistStorage.Save(self.IStorage, 1)
            self.IStorage.Commit(0)
        return S_OK

    def GetMoniker(self, dwAssign, dwWhichMoniker):
        print("GetMoniker " + str(dwAssign) + " " + str(dwWhichMoniker))

    def GetContainer(self):
        print("GetContainer")

    def ShowObject(self):
        print("ShowObject")

    def OnShowWindow(self, fShow):
        print("ShowObject" + str(fShow))

    def RequestNewObjectLayout(self):
        print("RequestNewObjectLayout")


import pytest


@pytest.mark.xfail
def test():
    # create a LockBytes object and
    # wrap it as a COM object
    #       import win32com.server.dispatcher
    # , useDispatcher=win32com.server.dispatcher.DispatcherWin32trace)
    lbcom = win32com.server.util.wrap(LockBytes(), pythoncom.IID_ILockBytes)

    # create a structured storage on the ILockBytes object
    stcom = pythoncom.StgCreateDocfileOnILockBytes(
        lbcom,
        storagecon.STGM_DIRECT | storagecon.STGM_CREATE | storagecon.STGM_READWRITE | storagecon.STGM_SHARE_EXCLUSIVE,
        0)

    # create our ClientSite
    ocs = OleClientSite()
    # wrap it as a COM object
    ocscom = win32com.server.util.wrap(ocs, axcontrol.IID_IOleClientSite)

    # create a Word OLE Document, connect it to our site and our storage
    oocom = axcontrol.OleCreate("{00020906-0000-0000-C000-000000000046}",
                                axcontrol.IID_IOleObject,
                                0,
                                (0,),
                                ocscom,
                                stcom,
                                )

    mf = win32ui.GetMainFrame()
    hwnd = mf.GetSafeHwnd()

    # Set the host and document name
    # for unknown reason document name becomes hostname, and document name
    # is not set, debugged it, but don't know where the problem is?
    oocom.SetHostNames("OTPython", "This is Cool")

    # activate the OLE document
    oocom.DoVerb(-1, ocscom, 0, hwnd, mf.GetWindowRect())

    # set the hostnames again
    oocom.SetHostNames("OTPython2", "ThisisCool2")

    # get IDispatch of Word
    doc = win32com.client.Dispatch(
        oocom.QueryInterface(
            pythoncom.IID_IDispatch))

    # get IPersistStorage of Word
    dpcom = oocom.QueryInterface(pythoncom.IID_IPersistStorage)

    # let our ClientSite know the interfaces
    ocs.SetIPersistStorage(dpcom)
    ocs.SetIStorage(stcom)

    # use IDispatch to do the Office Word test
    # pasted from TestOffice.py

    wrange = doc.Range()
    for i in range(10):
        wrange.InsertAfter("Hello from Python %d\n" % i)
    paras = doc.Paragraphs
    for i in range(len(paras)):
        paras[i]().Font.ColorIndex = i + 1
        paras[i]().Font.Size = 12 + (4 * i)
    # XXX - note that
    # for para in paras:
    #       para().Font...
    # doesnt seem to work - no error, just doesnt work
    # Should check if it works for VB!

    dpcom.Save(stcom, 0)
    dpcom.HandsOffStorage()
    # oocom.Close(axcontrol.OLECLOSE_NOSAVE) # or OLECLOSE_SAVEIFDIRTY, but it
    # fails???

    # Save the ILockBytes data to "persist2.doc"
    lbcom.Flush()

    # exiting Winword will automatically update the ILockBytes data
    # and flush it to "%TEMP%\persist.doc"
    doc.Application.Quit()


if __name__ == '__main__':
    test()
    pythoncom.CoUninitialize()
    CheckClean()



import pytest

# from win32ui import *


@pytest.mark.skip
def test_AddToRecentFileList():
    AddToRecentFileList()


@pytest.mark.skip
def test_ComparePath():
    ComparePath()


@pytest.mark.skip
def test_CreateBitmap():
    CreateBitmap()


@pytest.mark.skip
def test_CreateBitmapFromHandle():
    CreateBitmapFromHandle()


@pytest.mark.skip
def test_CreateBrush():
    CreateBrush()


@pytest.mark.skip
def test_CreateButton():
    CreateButton()


@pytest.mark.skip
def test_CreateColorDialog():
    CreateColorDialog()


@pytest.mark.skip
def test_CreateControl():
    CreateControl()


@pytest.mark.skip
def test_CreateControlBar():
    CreateControlBar()


@pytest.mark.skip
def test_CreateCtrlView():
    CreateCtrlView()


@pytest.mark.skip
def test_CreateDC():
    CreateDC()


@pytest.mark.skip
def test_CreateDCFromHandle():
    CreateDCFromHandle()


@pytest.mark.skip
def test_CreateDebuggerThread():
    CreateDebuggerThread()


@pytest.mark.skip
def test_CreateDialog():
    CreateDialog()


@pytest.mark.skip
def test_CreateDialogBar():
    CreateDialogBar()


@pytest.mark.skip
def test_CreateDialogIndirect():
    CreateDialogIndirect()


@pytest.mark.skip
def test_CreateDocTemplate():
    CreateDocTemplate()


@pytest.mark.skip
def test_CreateEdit():
    CreateEdit()


@pytest.mark.skip
def test_CreateEditView():
    CreateEditView()


@pytest.mark.skip
def test_CreateFileDialog():
    CreateFileDialog()


@pytest.mark.skip
def test_CreateFont():
    CreateFont()


@pytest.mark.skip
def test_CreateFontDialog():
    CreateFontDialog()


@pytest.mark.skip
def test_CreateFormView():
    CreateFormView()


@pytest.mark.skip
def test_CreateFrame():
    CreateFrame()


@pytest.mark.skip
def test_CreateImageList():
    CreateImageList()


@pytest.mark.skip
def test_CreateListCtrl():
    CreateListCtrl()


@pytest.mark.skip
def test_CreateListView():
    CreateListView()


@pytest.mark.skip
def test_CreateMDIChild():
    CreateMDIChild()


@pytest.mark.skip
def test_CreateMDIFrame():
    CreateMDIFrame()


@pytest.mark.skip
def test_CreateMenu():
    CreateMenu()


@pytest.mark.skip
def test_CreatePalette():
    CreatePalette()


@pytest.mark.skip
def test_CreatePen():
    CreatePen()


@pytest.mark.skip
def test_CreatePopupMenu():
    CreatePopupMenu()


@pytest.mark.skip
def test_CreatePrintDialog():
    CreatePrintDialog()


@pytest.mark.skip
def test_CreateProgressCtrl():
    CreateProgressCtrl()


@pytest.mark.skip
def test_CreatePropertyPage():
    CreatePropertyPage()


@pytest.mark.skip
def test_CreatePropertyPageIndirect():
    CreatePropertyPageIndirect()


@pytest.mark.skip
def test_CreatePropertySheet():
    CreatePropertySheet()


@pytest.mark.skip
def test_CreateRectRgn():
    CreateRectRgn()


@pytest.mark.skip
def test_CreateRgn():
    CreateRgn()


@pytest.mark.skip
def test_CreateRichEditCtrl():
    CreateRichEditCtrl()


@pytest.mark.skip
def test_CreateRichEditDocTemplate():
    CreateRichEditDocTemplate()


@pytest.mark.skip
def test_CreateRichEditView():
    CreateRichEditView()


@pytest.mark.skip
def test_CreateSliderCtrl():
    CreateSliderCtrl()


@pytest.mark.skip
def test_CreateSplitter():
    CreateSplitter()


@pytest.mark.skip
def test_CreateStatusBar():
    CreateStatusBar()


@pytest.mark.skip
def test_CreateStatusBarCtrl():
    CreateStatusBarCtrl()


@pytest.mark.skip
def test_CreateThread():
    CreateThread()


@pytest.mark.skip
def test_CreateToolBar():
    CreateToolBar()


@pytest.mark.skip
def test_CreateToolBarCtrl():
    CreateToolBarCtrl()


@pytest.mark.skip
def test_CreateToolTipCtrl():
    CreateToolTipCtrl()


@pytest.mark.skip
def test_CreateTreeCtrl():
    CreateTreeCtrl()


@pytest.mark.skip
def test_CreateTreeView():
    CreateTreeView()


@pytest.mark.skip
def test_CreateView():
    CreateView()


@pytest.mark.skip
def test_CreateWindowFromHandle():
    CreateWindowFromHandle()


@pytest.mark.skip
def test_CreateWnd():
    CreateWnd()


@pytest.mark.skip
def test_DestroyDebuggerThread():
    DestroyDebuggerThread()


@pytest.mark.skip
def test_DisplayTraceback():
    DisplayTraceback()


@pytest.mark.skip
def test_DoWaitCursor():
    DoWaitCursor()


@pytest.mark.skip
def test_Enable3dControls():
    Enable3dControls()


@pytest.mark.skip
def test_EnableControlContainer():
    EnableControlContainer()


@pytest.mark.skip
def test_FindWindow():
    FindWindow()


@pytest.mark.skip
def test_FindWindowEx():
    FindWindowEx()


@pytest.mark.skip
def test_FullPath():
    FullPath()


@pytest.mark.skip
def test_GetActiveWindow():
    GetActiveWindow()


@pytest.mark.skip
def test_GetApp():
    GetApp()


@pytest.mark.skip
def test_GetAppName():
    GetAppName()


@pytest.mark.skip
def test_GetAppRegistryKey():
    GetAppRegistryKey()


@pytest.mark.skip
def test_GetBytes():
    GetBytes()


@pytest.mark.skip
def test_GetCommandLine():
    GetCommandLine()


@pytest.mark.skip
def test_GetDeviceCaps():
    GetDeviceCaps()


@pytest.mark.skip
def test_GetFileTitle():
    GetFileTitle()


@pytest.mark.skip
def test_GetFocus():
    GetFocus()


@pytest.mark.skip
def test_GetForegroundWindow():
    GetForegroundWindow()


@pytest.mark.skip
def test_GetHalftoneBrush():
    GetHalftoneBrush()


@pytest.mark.skip
def test_GetInitialStateRequest():
    GetInitialStateRequest()


@pytest.mark.skip
def test_GetMainFrame():
    GetMainFrame()


@pytest.mark.skip
def test_GetName():
    GetName()


@pytest.mark.skip
def test_GetProfileFileName():
    GetProfileFileName()


@pytest.mark.skip
def test_GetProfileVal():
    GetProfileVal()


@pytest.mark.skip
def test_GetRecentFileList():
    GetRecentFileList()


@pytest.mark.skip
def test_GetResource():
    GetResource()


@pytest.mark.skip
def test_GetThread():
    GetThread()


@pytest.mark.skip
def test_GetType():
    GetType()


@pytest.mark.skip
def test_InitRichEdit():
    InitRichEdit()


@pytest.mark.skip
def test_InstallCallbackCaller():
    InstallCallbackCaller()


@pytest.mark.skip
def test_IsDebug():
    IsDebug()


@pytest.mark.skip
def test_IsObject():
    IsObject()


@pytest.mark.skip
def test_IsWin32s():
    IsWin32s()


@pytest.mark.skip
def test_LoadDialogResource():
    LoadDialogResource()


@pytest.mark.skip
def test_LoadLibrary():
    LoadLibrary()


@pytest.mark.skip
def test_LoadMenu():
    LoadMenu()


@pytest.mark.skip
def test_LoadStdProfileSettings():
    LoadStdProfileSettings()


@pytest.mark.skip
def test_LoadString():
    LoadString()


@pytest.mark.skip
def test_MessageBox():
    MessageBox()


@pytest.mark.skip
def test_OutputDebugString():
    OutputDebugString()


@pytest.mark.skip
def test_PrintTraceback():
    PrintTraceback()


@pytest.mark.skip
def test_PumpWaitingMessages():
    PumpWaitingMessages()


@pytest.mark.skip
def test_RegisterWndClass():
    RegisterWndClass()


@pytest.mark.skip
def test_RemoveRecentFile():
    RemoveRecentFile()


@pytest.mark.skip
def test_SetAppHelpPath():
    SetAppHelpPath()


@pytest.mark.skip
def test_SetAppName():
    SetAppName()


@pytest.mark.skip
def test_SetCurrentInstanceHandle():
    SetCurrentInstanceHandle()


@pytest.mark.skip
def test_SetCurrentResourceHandle():
    SetCurrentResourceHandle()


@pytest.mark.skip
def test_SetDialogBkColor():
    SetDialogBkColor()


@pytest.mark.skip
def test_SetProfileFileName():
    SetProfileFileName()


@pytest.mark.skip
def test_SetRegistryKey():
    SetRegistryKey()


@pytest.mark.skip
def test_SetResource():
    SetResource()


@pytest.mark.skip
def test_SetStatusText():
    SetStatusText()


@pytest.mark.skip
def test_StartDebuggerPump():
    StartDebuggerPump()


@pytest.mark.skip
def test_StopDebuggerPump():
    StopDebuggerPump()


@pytest.mark.skip
def test_TranslateMessage():
    TranslateMessage()


@pytest.mark.skip
def test_TranslateVirtualKey():
    TranslateVirtualKey()


@pytest.mark.skip
def test_WinHelp():
    WinHelp()


@pytest.mark.skip
def test_WriteProfileVal():
    WriteProfileVal()



import unittest

import win32com.test.util
from win32com.client import GetObject


class Simple(win32com.test.util.TestCase):
    def testit(self):
        cses = GetObject("WinMgMts:").InstancesOf("Win32_Process")
        vals = []
        for cs in cses:
            val = cs.Properties_("Caption").Value
            vals.append(val)
        assert not (len(vals) < 5), \
            "We only found %d processes!" % \
            len(vals)


if __name__ == '__main__':
    unittest.main()



import pytest

from pythoncom import *


@pytest.mark.skip
def test_CoCreateFreeThreadedMarshaler():
    CoCreateFreeThreadedMarshaler()


@pytest.mark.skip
def test_CoCreateInstance():
    CoCreateInstance()


@pytest.mark.skip
def test_CoCreateInstanceEx():
    CoCreateInstanceEx()


@pytest.mark.skip
def test_CoFreeUnusedLibraries():
    CoFreeUnusedLibraries()


@pytest.mark.skip
def test_CoGetInterfaceAndReleaseStream():
    CoGetInterfaceAndReleaseStream()


@pytest.mark.skip
def test_CoGetObject():
    CoGetObject()


@pytest.mark.skip
def test_CoInitialize():
    CoInitialize()


@pytest.mark.skip
def test_CoInitializeEx():
    CoInitializeEx()


@pytest.mark.skip
def test_CoInitializeSecurity():
    CoInitializeSecurity()


@pytest.mark.skip
def test_CoMarshalInterThreadInterfaceInStream():
    CoMarshalInterThreadInterfaceInStream()


@pytest.mark.skip
def test_CoMarshalInterface():
    CoMarshalInterface()


@pytest.mark.skip
def test_CoRegisterClassObject():
    CoRegisterClassObject()


@pytest.mark.skip
def test_CoReleaseMarshalData():
    CoReleaseMarshalData()


@pytest.mark.skip
def test_CoResumeClassObjects():
    CoResumeClassObjects()


@pytest.mark.skip
def test_CoRevokeClassObject():
    CoRevokeClassObject()


@pytest.mark.skip
def test_CoTreatAsClass():
    CoTreatAsClass()


@pytest.mark.skip
def test_CoUninitialize():
    CoUninitialize()


@pytest.mark.skip
def test_CoUnmarshalInterface():
    CoUnmarshalInterface()


@pytest.mark.skip
def test_CoWaitForMultipleHandles():
    CoWaitForMultipleHandles()


@pytest.mark.skip
def test_Connect():
    Connect()


@pytest.mark.skip
def test_CreateBindCtx():
    CreateBindCtx()


@pytest.mark.skip
def test_CreateFileMoniker():
    CreateFileMoniker()


@pytest.mark.skip
def test_CreateGuid():
    CreateGuid()


@pytest.mark.skip
def test_CreateILockBytesOnHGlobal():
    CreateILockBytesOnHGlobal()


@pytest.mark.skip
def test_CreateItemMoniker():
    CreateItemMoniker()


@pytest.mark.skip
def test_CreatePointerMoniker():
    CreatePointerMoniker()


@pytest.mark.skip
def test_CreateStreamOnHGlobal():
    CreateStreamOnHGlobal()


@pytest.mark.skip
def test_CreateTypeLib():
    CreateTypeLib()


@pytest.mark.skip
def test_CreateTypeLib2():
    CreateTypeLib2()


@pytest.mark.skip
def test_CreateURLMoniker():
    CreateURLMoniker()


@pytest.mark.skip
def test_DoDragDrop():
    DoDragDrop()


@pytest.mark.skip
def test_EnableQuitMessage():
    EnableQuitMessage()


@pytest.mark.skip
def test_FUNCDESC():
    FUNCDESC()


@pytest.mark.skip
def test_FmtIdToPropStgName():
    FmtIdToPropStgName()


@pytest.mark.skip
def test_GetActiveObject():
    GetActiveObject()


@pytest.mark.skip
def test_GetClassFile():
    GetClassFile()


@pytest.mark.skip
def test_GetFacilityString():
    GetFacilityString()


@pytest.mark.skip
def test_GetRecordFromGuids():
    GetRecordFromGuids()


@pytest.mark.skip
def test_GetRecordFromTypeInfo():
    GetRecordFromTypeInfo()


@pytest.mark.skip
def test_GetRunningObjectTable():
    GetRunningObjectTable()


@pytest.mark.skip
def test_GetScodeRangeString():
    GetScodeRangeString()


@pytest.mark.skip
def test_GetScodeString():
    GetScodeString()


@pytest.mark.skip
def test_GetSeverityString():
    GetSeverityString()


@pytest.mark.skip
def test_IsGatewayRegistered():
    IsGatewayRegistered()


@pytest.mark.skip
def test_LoadRegTypeLib():
    LoadRegTypeLib()


@pytest.mark.skip
def test_LoadTypeLib():
    LoadTypeLib()


@pytest.mark.skip
def test_MakePyFactory():
    MakePyFactory()


@pytest.mark.skip
def test_MkParseDisplayName():
    MkParseDisplayName()


@pytest.mark.skip
def test_New():
    New()


@pytest.mark.skip
def test_ObjectFromAddress():
    ObjectFromAddress()


@pytest.mark.skip
def test_ObjectFromLresult():
    ObjectFromLresult()


@pytest.mark.skip
def test_OleFlushClipboard():
    OleFlushClipboard()


@pytest.mark.skip
def test_OleGetClipboard():
    OleGetClipboard()


@pytest.mark.skip
def test_OleInitialize():
    OleInitialize()


@pytest.mark.skip
def test_OleIsCurrentClipboard():
    OleIsCurrentClipboard()


@pytest.mark.skip
def test_OleLoad():
    OleLoad()


@pytest.mark.skip
def test_OleLoadFromStream():
    OleLoadFromStream()


@pytest.mark.skip
def test_OleSaveToStream():
    OleSaveToStream()


@pytest.mark.skip
def test_OleSetClipboard():
    OleSetClipboard()


@pytest.mark.skip
def test_ProgIDFromCLSID():
    ProgIDFromCLSID()


@pytest.mark.skip
def test_PropStgNameToFmtId():
    PropStgNameToFmtId()


@pytest.mark.skip
@pytest.mark.skip
def test_PumpMessages():
    PumpMessages()


@pytest.mark.skip
def test_PumpWaitingMessages():
    PumpWaitingMessages()


@pytest.mark.skip
def test_QueryPathOfRegTypeLib():
    QueryPathOfRegTypeLib()


@pytest.mark.skip
def test_ReadClassStg():
    ReadClassStg()


@pytest.mark.skip
def test_ReadClassStm():
    ReadClassStm()


@pytest.mark.skip
def test_RegisterActiveObject():
    RegisterActiveObject()


@pytest.mark.skip
def test_RegisterDragDrop():
    RegisterDragDrop()


@pytest.mark.skip
def test_RegisterTypeLib():
    RegisterTypeLib()


@pytest.mark.xfail
@pytest.mark.skip
def test_RevokeActiveObject():
    RevokeActiveObject()


@pytest.mark.skip
def test_RevokeDragDrop():
    RevokeDragDrop()


@pytest.mark.skip
def test_STGMEDIUM():
    STGMEDIUM()


@pytest.mark.skip
def test_StgCreateDocfile():
    StgCreateDocfile()


@pytest.mark.skip
def test_StgCreateDocfileOnILockBytes():
    StgCreateDocfileOnILockBytes()


@pytest.mark.skip
def test_StgIsStorageFile():
    StgIsStorageFile()


@pytest.mark.skip
def test_StgOpenStorage():
    StgOpenStorage()


@pytest.mark.skip
def test_StgOpenStorageEx():
    StgOpenStorageEx()


@pytest.mark.skip
def test_TYPEATTR():
    TYPEATTR()


@pytest.mark.skip
def test_UnRegisterTypeLib():
    UnRegisterTypeLib()


@pytest.mark.skip
def test_UnwrapObject():
    UnwrapObject()


@pytest.mark.skip
def test_VARDESC():
    VARDESC()


@pytest.mark.skip
def test_WrapObject():
    WrapObject()


@pytest.mark.skip
def test_WriteClassStg():
    WriteClassStg()


@pytest.mark.skip
def test_WriteClassStm():
    WriteClassStm()


@pytest.mark.skip
@pytest.mark.skip
def test_GetInterfaceCount():
    GetInterfaceCount()


@pytest.mark.skip
def test_GetInterfaceCount():
    GetInterfaceCount()



import pytest

# from win32uiole import *


@pytest.mark.skip
def test_AfxOleInit():
    AfxOleInit()


@pytest.mark.skip
def test_CreateInsertDialog():
    CreateInsertDialog()


@pytest.mark.skip
def test_CreateOleClientItem():
    CreateOleClientItem()


@pytest.mark.skip
def test_CreateOleDocument():
    CreateOleDocument()


@pytest.mark.skip
def test_DaoGetEngine():
    DaoGetEngine()


@pytest.mark.skip
def test_EnableNotRespondingDialog():
    EnableNotRespondingDialog()


@pytest.mark.skip
def test_EnableNotRespondingDialog():
    EnableNotRespondingDialog()


@pytest.mark.skip
def test_GetIDispatchForWindow():
    GetIDispatchForWindow()


@pytest.mark.skip
def test_OleGetUserCtrl():
    OleGetUserCtrl()


@pytest.mark.skip
def test_OleSetUserCtrl():
    OleSetUserCtrl()


@pytest.mark.skip
def test_SetMessagePendingDelay():
    SetMessagePendingDelay()



import pytest
import pytest

from directsound import *


def test_DSBCAPS():
    DSBCAPS()


def test_DSBUFFERDESC():
    DSBUFFERDESC()


def test_DSCAPS():
    DSCAPS()


def test_DSCBCAPS():
    DSCBCAPS()


def test_DSCBUFFERDESC():
    DSCBUFFERDESC()


def test_DSCCAPS():
    DSCCAPS()


@pytest.mark.skip
def test_DirectSoundCaptureCreate():
    DirectSoundCaptureCreate()


def test_DirectSoundCaptureEnumerate():
    DirectSoundCaptureEnumerate()


@pytest.mark.xfail
def test_DirectSoundCreate():
    DirectSoundCreate()


def test_DirectSoundEnumerate():
    DirectSoundEnumerate()



import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32cred import *
@pytest.mark.xfail
def test_CredDelete():
    CredDelete()     



@pytest.mark.xfail
def test_CredEnumerate():
    CredEnumerate()     



@pytest.mark.xfail
def test_CredGetTargetInfo():
    CredGetTargetInfo()     



@pytest.mark.xfail
def test_CredIsMarshaledCredential():
    CredIsMarshaledCredential()     



@pytest.mark.xfail
def test_CredMarshalCredential():
    CredMarshalCredential()     



@pytest.mark.xfail
def test_CredRead():
    CredRead()     



@pytest.mark.xfail
def test_CredReadDomainCredentials():
    CredReadDomainCredentials()     



@pytest.mark.xfail
def test_CredRename():
    CredRename()     



@pytest.mark.xfail
def test_CredUICmdLinePromptForCredentials():
    CredUICmdLinePromptForCredentials()     



@pytest.mark.xfail
def test_CredUIConfirmCredentials():
    CredUIConfirmCredentials()     



@pytest.mark.xfail
def test_CredUIParseUserName():
    CredUIParseUserName()     



@pytest.mark.xfail
def test_CredUIPromptForCredentials():
    CredUIPromptForCredentials()     



@pytest.mark.xfail
def test_CredUIReadSSOCredW():
    CredUIReadSSOCredW()     



@pytest.mark.xfail
def test_CredUIStoreSSOCredW():
    CredUIStoreSSOCredW()     



@pytest.mark.xfail
def test_CredUnmarshalCredential():
    CredUnmarshalCredential()     



@pytest.mark.xfail
def test_CredWrite():
    CredWrite()     



@pytest.mark.xfail
def test_CredWriteDomainCredentials():
    CredWriteDomainCredentials()     





from wincerapi import *
def test_CeCheckPassword():
    CeCheckPassword()     



def test_CeCopyFile():
    CeCopyFile()     



def test_CeCreateDirectory():
    CeCreateDirectory()     



def test_CeCreateFile():
    CeCreateFile()     



def test_CeDeleteFile():
    CeDeleteFile()     



def test_CeGetDesktopDeviceCaps():
    CeGetDesktopDeviceCaps()     



def test_CeGetFileAttributes():
    CeGetFileAttributes()     



def test_CeGetFileSize():
    CeGetFileSize()     



def test_CeGetSpecialFolderPath():
    CeGetSpecialFolderPath()     



def test_CeGetStoreInformation():
    CeGetStoreInformation()     



def test_CeGetSystemInfo():
    CeGetSystemInfo()     



def test_CeGetSystemMetrics():
    CeGetSystemMetrics()     



def test_CeGetSystemPowerStatusEx():
    CeGetSystemPowerStatusEx()     



def test_CeGetTempPath():
    CeGetTempPath()     



def test_CeGetVersionEx():
    CeGetVersionEx()     



def test_CeGlobalMemoryStatus():
    CeGlobalMemoryStatus()     



def test_CeMoveFile():
    CeMoveFile()     



def test_CeRapiInit():
    CeRapiInit()     



def test_CeRapiInitEx():
    CeRapiInitEx()     



def test_CeRapiUninit():
    CeRapiUninit()     



def test_CeReadFile():
    CeReadFile()     



def test_CeRemoveDirectory():
    CeRemoveDirectory()     



def test_CeSHCreateShortcut():
    CeSHCreateShortcut()     



def test_CeSHGetShortcutTarget():
    CeSHGetShortcutTarget()     



def test_CeSetFileAttributes():
    CeSetFileAttributes()     



def test_CreateProcess():
    CreateProcess()     



def test_FindFiles():
    FindFiles()     



def test_WriteFile():
    WriteFile()     





import pytest

from win32api import *


@pytest.mark.skip
def test_AbortSystemShutdown():
    AbortSystemShutdown()


@pytest.mark.skip
def test_Apply():
    Apply()


@pytest.mark.skip
def test_Beep():
    Beep()


@pytest.mark.skip
def test_BeginUpdateResource():
    BeginUpdateResource()


@pytest.mark.skip
def test_ChangeDisplaySettings():
    ChangeDisplaySettings()


@pytest.mark.skip
def test_ChangeDisplaySettingsEx():
    ChangeDisplaySettingsEx()


@pytest.mark.skip
def test_ClipCursor():
    ClipCursor()


@pytest.mark.skip
def test_CloseHandle():
    CloseHandle()


@pytest.mark.skip
def test_CopyFile():
    CopyFile()


@pytest.mark.skip
def test_DebugBreak():
    DebugBreak()


@pytest.mark.skip
def test_DeleteFile():
    DeleteFile()


@pytest.mark.skip
def test_DragFinish():
    DragFinish()


@pytest.mark.skip
def test_DragQueryFile():
    DragQueryFile()


@pytest.mark.skip
def test_DuplicateHandle():
    DuplicateHandle()


@pytest.mark.skip
def test_EndUpdateResource():
    EndUpdateResource()


@pytest.mark.skip
def test_EnumDisplayDevices():
    EnumDisplayDevices()


@pytest.mark.skip
def test_EnumDisplayMonitors():
    EnumDisplayMonitors()


@pytest.mark.skip
def test_EnumDisplaySettings():
    EnumDisplaySettings()


@pytest.mark.skip
def test_EnumDisplaySettingsEx():
    EnumDisplaySettingsEx()


@pytest.mark.skip
def test_EnumResourceLanguages():
    EnumResourceLanguages()


@pytest.mark.skip
def test_EnumResourceNames():
    EnumResourceNames()


@pytest.mark.skip
def test_EnumResourceTypes():
    EnumResourceTypes()


@pytest.mark.skip
def test_ExitWindows():
    ExitWindows()


@pytest.mark.skip
def test_ExitWindowsEx():
    ExitWindowsEx()


@pytest.mark.skip
def test_ExpandEnvironmentStrings():
    ExpandEnvironmentStrings()


@pytest.mark.skip
def test_FindCloseChangeNotification():
    FindCloseChangeNotification()


@pytest.mark.skip
def test_FindExecutable():
    FindExecutable()


@pytest.mark.skip
def test_FindFiles():
    FindFiles()


@pytest.mark.skip
def test_FindFirstChangeNotification():
    FindFirstChangeNotification()


@pytest.mark.skip
def test_FindNextChangeNotification():
    FindNextChangeNotification()


@pytest.mark.skip
def test_FormatMessage():
    FormatMessage()


@pytest.mark.skip
def test_FormatMessageW():
    FormatMessageW()


@pytest.mark.skip
def test_FreeLibrary():
    FreeLibrary()


@pytest.mark.skip
def test_GenerateConsoleCtrlEvent():
    GenerateConsoleCtrlEvent()


@pytest.mark.skip
def test_GetAsyncKeyState():
    GetAsyncKeyState()


@pytest.mark.skip
def test_GetCommandLine():
    GetCommandLine()


@pytest.mark.skip
def test_GetComputerName():
    GetComputerName()


@pytest.mark.skip
def test_GetComputerNameEx():
    GetComputerNameEx()


@pytest.mark.skip
def test_GetComputerObjectName():
    GetComputerObjectName()


@pytest.mark.skip
def test_GetConsoleTitle():
    GetConsoleTitle()


@pytest.mark.skip
def test_GetCurrentProcess():
    GetCurrentProcess()


@pytest.mark.skip
def test_GetCurrentProcessId():
    GetCurrentProcessId()


@pytest.mark.skip
def test_GetCurrentThread():
    GetCurrentThread()


@pytest.mark.skip
def test_GetCurrentThreadId():
    GetCurrentThreadId()


@pytest.mark.skip
def test_GetCursorPos():
    GetCursorPos()


@pytest.mark.skip
def test_GetDateFormat():
    GetDateFormat()


@pytest.mark.skip
def test_GetDiskFreeSpace():
    GetDiskFreeSpace()


@pytest.mark.skip
def test_GetDiskFreeSpaceEx():
    GetDiskFreeSpaceEx()


@pytest.mark.skip
def test_GetDllDirectory():
    GetDllDirectory()


@pytest.mark.skip
def test_GetDomainName():
    GetDomainName()


@pytest.mark.skip
def test_GetEnvironmentVariable():
    GetEnvironmentVariable()


@pytest.mark.skip
def test_GetFileAttributes():
    GetFileAttributes()


@pytest.mark.skip
def test_GetFileVersionInfo():
    GetFileVersionInfo()


@pytest.mark.skip
def test_GetFocus():
    GetFocus()


@pytest.mark.skip
def test_GetFullPathName():
    GetFullPathName()


@pytest.mark.skip
def test_GetHandleInformation():
    GetHandleInformation()


@pytest.mark.skip
def test_GetKeyState():
    GetKeyState()


@pytest.mark.skip
def test_GetKeyboardLayout():
    GetKeyboardLayout()


@pytest.mark.skip
def test_GetKeyboardLayoutList():
    GetKeyboardLayoutList()


@pytest.mark.skip
def test_GetKeyboardState():
    GetKeyboardState()


@pytest.mark.skip
def test_GetLastError():
    GetLastError()


@pytest.mark.skip
def test_GetLastInputInfo():
    GetLastInputInfo()


@pytest.mark.skip
def test_GetLocalTime():
    GetLocalTime()


@pytest.mark.skip
def test_GetLogicalDriveStrings():
    GetLogicalDriveStrings()


@pytest.mark.skip
def test_GetLogicalDrives():
    GetLogicalDrives()


@pytest.mark.skip
def test_GetLongPathName():
    GetLongPathName()


@pytest.mark.skip
def test_GetLongPathNameW():
    GetLongPathNameW()


@pytest.mark.skip
def test_GetModuleFileName():
    GetModuleFileName()


@pytest.mark.skip
def test_GetModuleFileNameW():
    GetModuleFileNameW()


@pytest.mark.skip
def test_GetModuleHandle():
    GetModuleHandle()


@pytest.mark.skip
def test_GetMonitorInfo():
    GetMonitorInfo()


@pytest.mark.skip
def test_GetNativeSystemInfo():
    GetNativeSystemInfo()


@pytest.mark.skip
def test_GetProcAddress():
    GetProcAddress()


@pytest.mark.skip
def test_GetProfileSection():
    GetProfileSection()


@pytest.mark.skip
def test_GetProfileVal():
    GetProfileVal()


@pytest.mark.skip
def test_GetPwrCapabilities():
    GetPwrCapabilities()


@pytest.mark.skip
def test_GetShortPathName():
    GetShortPathName()


@pytest.mark.skip
def test_GetStdHandle():
    GetStdHandle()


@pytest.mark.skip
def test_GetSysColor():
    GetSysColor()


@pytest.mark.skip
def test_GetSystemdefaultLCID():
    GetSystemdefaultLCID()


@pytest.mark.skip
def test_GetSystemdefaultLangID():
    GetSystemdefaultLangID()


@pytest.mark.skip
def test_GetSystemDirectory():
    GetSystemDirectory()


@pytest.mark.skip
def test_GetSystemFileCacheSize():
    GetSystemFileCacheSize()


@pytest.mark.skip
def test_GetSystemInfo():
    GetSystemInfo()


@pytest.mark.skip
def test_GetSystemMetrics():
    GetSystemMetrics()


@pytest.mark.skip
def test_GetSystemTime():
    GetSystemTime()


@pytest.mark.skip
def test_GetTempFileName():
    GetTempFileName()


@pytest.mark.skip
def test_GetTempPath():
    GetTempPath()


@pytest.mark.skip
def test_GetThreadLocale():
    GetThreadLocale()


@pytest.mark.skip
def test_GetTickCount():
    GetTickCount()


@pytest.mark.skip
def test_GetTimeFormat():
    GetTimeFormat()


@pytest.mark.skip
def test_GetTimeZoneInformation():
    GetTimeZoneInformation()


@pytest.mark.skip
def test_GetUserdefaultLCID():
    GetUserdefaultLCID()


@pytest.mark.skip
def test_GetUserdefaultLangID():
    GetUserdefaultLangID()


@pytest.mark.skip
def test_GetUserName():
    GetUserName()


@pytest.mark.skip
def test_GetUserNameEx():
    GetUserNameEx()


@pytest.mark.skip
def test_GetVersion():
    GetVersion()


@pytest.mark.skip
def test_GetVersionEx():
    GetVersionEx()


@pytest.mark.skip
def test_GetVolumeInformation():
    GetVolumeInformation()


@pytest.mark.skip
def test_GetWindowLong():
    GetWindowLong()


@pytest.mark.skip
def test_GetWindowsDirectory():
    GetWindowsDirectory()


@pytest.mark.skip
def test_GlobalMemoryStatus():
    GlobalMemoryStatus()


@pytest.mark.skip
def test_GlobalMemoryStatusEx():
    GlobalMemoryStatusEx()


@pytest.mark.skip
def test_HIBYTE():
    HIBYTE()


@pytest.mark.skip
def test_HIWORD():
    HIWORD()


@pytest.mark.skip
def test_InitiateSystemShutdown():
    InitiateSystemShutdown()


@pytest.mark.skip
def test_LOBYTE():
    LOBYTE()


@pytest.mark.skip
def test_LOWORD():
    LOWORD()


@pytest.mark.skip
def test_LoadCursor():
    LoadCursor()


@pytest.mark.skip
def test_LoadKeyboardLayout():
    LoadKeyboardLayout()


@pytest.mark.skip
def test_LoadLibrary():
    LoadLibrary()


@pytest.mark.skip
def test_LoadLibraryEx():
    LoadLibraryEx()


@pytest.mark.skip
def test_LoadResource():
    LoadResource()


@pytest.mark.skip
def test_LoadString():
    LoadString()


@pytest.mark.skip
def test_MAKELANGID():
    MAKELANGID()


@pytest.mark.skip
def test_MAKELONG():
    MAKELONG()


@pytest.mark.skip
def test_MAKEWORD():
    MAKEWORD()


@pytest.mark.skip
def test_MessageBeep():
    MessageBeep()


@pytest.mark.skip
def test_MessageBox():
    MessageBox()


@pytest.mark.skip
def test_MonitorFromPoint():
    MonitorFromPoint()


@pytest.mark.skip
def test_MonitorFromRect():
    MonitorFromRect()


@pytest.mark.skip
def test_MonitorFromWindow():
    MonitorFromWindow()


@pytest.mark.skip
def test_MoveFile():
    MoveFile()


@pytest.mark.skip
def test_MoveFileEx():
    MoveFileEx()


@pytest.mark.skip
def test_OpenProcess():
    OpenProcess()


@pytest.mark.skip
def test_OutputDebugString():
    OutputDebugString()


@pytest.mark.skip
def test_PostMessage():
    PostMessage()


@pytest.mark.skip
def test_PostQuitMessage():
    PostQuitMessage()


@pytest.mark.skip
def test_PostThreadMessage():
    PostThreadMessage()


@pytest.mark.skip
def test_RGB():
    RGB()


@pytest.mark.skip
def test_RegCloseKey():
    RegCloseKey()


@pytest.mark.skip
def test_RegConnectRegistry():
    RegConnectRegistry()


@pytest.mark.skip
def test_RegCopyTree():
    RegCopyTree()


@pytest.mark.skip
def test_RegCreateKey():
    RegCreateKey()


@pytest.mark.skip
def test_RegCreateKeyEx():
    RegCreateKeyEx()


@pytest.mark.skip
def test_RegDeleteKey():
    RegDeleteKey()


@pytest.mark.skip
def test_RegDeleteKeyEx():
    RegDeleteKeyEx()


@pytest.mark.skip
def test_RegDeleteTree():
    RegDeleteTree()


@pytest.mark.skip
def test_RegDeleteValue():
    RegDeleteValue()


@pytest.mark.skip
def test_RegEnumKey():
    RegEnumKey()


@pytest.mark.skip
def test_RegEnumKeyEx():
    RegEnumKeyEx()


@pytest.mark.skip
def test_RegEnumKeyExW():
    RegEnumKeyExW()


@pytest.mark.skip
def test_RegEnumValue():
    RegEnumValue()


@pytest.mark.skip
def test_RegFlushKey():
    RegFlushKey()


@pytest.mark.skip
def test_RegGetKeySecurity():
    RegGetKeySecurity()


@pytest.mark.skip
def test_RegLoadKey():
    RegLoadKey()


@pytest.mark.skip
def test_RegNotifyChangeKeyValue():
    RegNotifyChangeKeyValue()


@pytest.mark.skip
def test_RegOpenCurrentUser():
    RegOpenCurrentUser()


@pytest.mark.skip
def test_RegOpenKey():
    RegOpenKey()


@pytest.mark.skip
def test_RegOpenKeyEx():
    RegOpenKeyEx()


@pytest.mark.skip
def test_RegOpenKeyTransacted():
    RegOpenKeyTransacted()


@pytest.mark.skip
def test_RegOverridePredefKey():
    RegOverridePredefKey()


@pytest.mark.skip
def test_RegQueryInfoKey():
    RegQueryInfoKey()


@pytest.mark.skip
def test_RegQueryInfoKeyW():
    RegQueryInfoKeyW()


@pytest.mark.skip
def test_RegQueryValue():
    RegQueryValue()


@pytest.mark.skip
def test_RegQueryValueEx():
    RegQueryValueEx()


@pytest.mark.skip
def test_RegRestoreKey():
    RegRestoreKey()


@pytest.mark.skip
def test_RegSaveKey():
    RegSaveKey()


@pytest.mark.skip
def test_RegSaveKeyEx():
    RegSaveKeyEx()


@pytest.mark.skip
def test_RegSetKeySecurity():
    RegSetKeySecurity()


@pytest.mark.skip
def test_RegSetValue():
    RegSetValue()


@pytest.mark.skip
def test_RegSetValueEx():
    RegSetValueEx()


@pytest.mark.skip
def test_RegUnLoadKey():
    RegUnLoadKey()


@pytest.mark.skip
def test_RegisterWindowMessage():
    RegisterWindowMessage()


@pytest.mark.skip
def test_SearchPath():
    SearchPath()


@pytest.mark.skip
def test_SendMessage():
    SendMessage()


@pytest.mark.skip
def test_SetClassLong():
    SetClassLong()


@pytest.mark.skip
def test_SetClassWord():
    SetClassWord()


@pytest.mark.skip
def test_SetConsoleCtrlHandler():
    SetConsoleCtrlHandler()


@pytest.mark.skip
def test_SetConsoleTitle():
    SetConsoleTitle()


@pytest.mark.skip
def test_SetCursor():
    SetCursor()


@pytest.mark.skip
def test_SetCursorPos():
    SetCursorPos()


@pytest.mark.skip
def test_SetDllDirectory():
    SetDllDirectory()


@pytest.mark.skip
def test_SetEnvironmentVariable():
    SetEnvironmentVariable()


@pytest.mark.skip
def test_SetErrorMode():
    SetErrorMode()


@pytest.mark.skip
def test_SetFileAttributes():
    SetFileAttributes()


@pytest.mark.skip
def test_SetHandleInformation():
    SetHandleInformation()


@pytest.mark.skip
def test_SetLastError():
    SetLastError()


@pytest.mark.skip
def test_SetLocalTime():
    SetLocalTime()


@pytest.mark.skip
def test_SetStdHandle():
    SetStdHandle()


@pytest.mark.skip
def test_SetSysColors():
    SetSysColors()


@pytest.mark.skip
def test_SetSystemFileCacheSize():
    SetSystemFileCacheSize()


@pytest.mark.skip
def test_SetSystemPowerState():
    SetSystemPowerState()


@pytest.mark.skip
def test_SetSystemTime():
    SetSystemTime()


@pytest.mark.skip
def test_SetThreadLocale():
    SetThreadLocale()


@pytest.mark.skip
def test_SetTimeZoneInformation():
    SetTimeZoneInformation()


@pytest.mark.skip
def test_SetWindowLong():
    SetWindowLong()


@pytest.mark.skip
def test_SetWindowWord():
    SetWindowWord()


@pytest.mark.skip
def test_ShellExecute():
    ShellExecute()


@pytest.mark.skip
def test_ShowCursor():
    ShowCursor()


@pytest.mark.skip
def test_Sleep():
    Sleep()


@pytest.mark.skip
def test_TerminateProcess():
    TerminateProcess()


@pytest.mark.skip
def test_Unicode():
    Unicode()


@pytest.mark.skip
def test_UpdateResource():
    UpdateResource()


@pytest.mark.skip
def test_VkKeyScan():
    VkKeyScan()


@pytest.mark.skip
def test_VkKeyScan():
    VkKeyScan()


@pytest.mark.skip
def test_WinExec():
    WinExec()


@pytest.mark.skip
def test_WinHelp():
    WinHelp()


@pytest.mark.skip
def test_WriteProfileSection():
    WriteProfileSection()


@pytest.mark.skip
def test_WriteProfileVal():
    WriteProfileVal()


@pytest.mark.skip
def test_keybd_event():
    keybd_event()


@pytest.mark.skip
def test_mouse_event():
    mouse_event()



import os

from . import gen_py
from win32._com import *
from win32._com import _univgw
from tempfile import gettempdir

__gen_path__ = os.path.join(gettempdir(), 'pywin32', 'gen_py')
gen_py.__path__.insert(0, __gen_path__)


import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32profile import *
@pytest.mark.xfail
def test_CreateEnvironmentBlock():
    CreateEnvironmentBlock()     



@pytest.mark.xfail
def test_DeleteProfile():
    DeleteProfile()     



@pytest.mark.xfail
def test_ExpandEnvironmentStringsForUser():
    ExpandEnvironmentStringsForUser()     



def test_GetAllUsersProfileDirectory():
    GetAllUsersProfileDirectory()     



def test_GetDefaultUserProfileDirectory():
    GetDefaultUserProfileDirectory()     



def test_GetEnvironmentStrings():
    GetEnvironmentStrings()     



def test_GetProfileType():
    GetProfileType()     



def test_GetProfilesDirectory():
    GetProfilesDirectory()     



@pytest.mark.xfail
def test_GetUserProfileDirectory():
    GetUserProfileDirectory()     



@pytest.mark.xfail
def test_LoadUserProfile():
    LoadUserProfile()     



@pytest.mark.xfail
def test_UnloadUserProfile():
    UnloadUserProfile()     





import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32security import *
def test_ACL():
    ACL()     



@pytest.mark.xfail
def test_AcceptSecurityContext():
    AcceptSecurityContext()     



@pytest.mark.xfail
def test_AcquireCredentialsHandle():
    AcquireCredentialsHandle()     



@pytest.mark.xfail
def test_AdjustTokenGroups():
    AdjustTokenGroups()     



@pytest.mark.xfail
def test_AdjustTokenPrivileges():
    AdjustTokenPrivileges()     



def test_AllocateLocallyUniqueId():
    AllocateLocallyUniqueId()     



@pytest.mark.xfail
def test_CheckTokenMembership():
    CheckTokenMembership()     



@pytest.mark.xfail
def test_ConvertSecurityDescriptorToStringSecurityDescriptor():
    ConvertSecurityDescriptorToStringSecurityDescriptor()     



@pytest.mark.xfail
def test_ConvertSidToStringSid():
    ConvertSidToStringSid()     



@pytest.mark.xfail
def test_ConvertStringSecurityDescriptorToSecurityDescriptor():
    ConvertStringSecurityDescriptorToSecurityDescriptor()     



@pytest.mark.xfail
def test_ConvertStringSidToSid():
    ConvertStringSidToSid()     



@pytest.mark.xfail
def test_CreateRestrictedToken():
    CreateRestrictedToken()     



@pytest.mark.xfail
def test_CreateWellKnownSid():
    CreateWellKnownSid()     



def test_CryptEnumProviders():
    CryptEnumProviders()     



@pytest.mark.xfail
def test_DsBind():
    DsBind()     



@pytest.mark.xfail
def test_DsCrackNames():
    DsCrackNames()     



@pytest.mark.xfail
def test_DsGetDcName():
    DsGetDcName()     



@pytest.mark.xfail
def test_DsGetSpn():
    DsGetSpn()     



@pytest.mark.xfail
def test_DsListDomainsInSite():
    DsListDomainsInSite()     



@pytest.mark.xfail
def test_DsListInfoForServer():
    DsListInfoForServer()     



@pytest.mark.xfail
def test_DsListRoles():
    DsListRoles()     



@pytest.mark.xfail
def test_DsListServersInSite():
    DsListServersInSite()     



@pytest.mark.xfail
def test_DsListServersInSite():
    DsListServersInSite()     



@pytest.mark.xfail
def test_DsListServersInSite():
    DsListServersInSite()     



@pytest.mark.xfail
def test_DsUnBind():
    DsUnBind()     



@pytest.mark.xfail
def test_DsWriteAccountSpn():
    DsWriteAccountSpn()     



@pytest.mark.xfail
def test_DuplicateToken():
    DuplicateToken()     



@pytest.mark.xfail
def test_DuplicateTokenEx():
    DuplicateTokenEx()     



def test_EnumerateSecurityPackages():
    EnumerateSecurityPackages()     



@pytest.mark.xfail
def test_GetBinarySid():
    GetBinarySid()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_GetFileSecurity():
    GetFileSecurity()     



@pytest.mark.xfail
def test_GetKernelObjectSecurity():
    GetKernelObjectSecurity()     



@pytest.mark.xfail
def test_GetNamedSecurityInfo():
    GetNamedSecurityInfo()     



@pytest.mark.xfail
def test_GetSecurityInfo():
    GetSecurityInfo()     



@pytest.mark.xfail
def test_GetTokenInformation():
    GetTokenInformation()     



@pytest.mark.xfail
def test_GetUserObjectSecurity():
    GetUserObjectSecurity()     



@pytest.mark.xfail
def test_ImpersonateAnonymousToken():
    ImpersonateAnonymousToken()     



@pytest.mark.xfail
def test_ImpersonateLoggedOnUser():
    ImpersonateLoggedOnUser()     



@pytest.mark.xfail
def test_ImpersonateNamedPipeClient():
    ImpersonateNamedPipeClient()     



@pytest.mark.xfail
def test_ImpersonateSelf():
    ImpersonateSelf()     



@pytest.mark.xfail
def test_InitializeSecurityContext():
    InitializeSecurityContext()     



@pytest.mark.xfail
def test_IsTokenRestricted():
    IsTokenRestricted()     



@pytest.mark.xfail
def test_LogonUser():
    LogonUser()     



@pytest.mark.xfail
def test_LogonUserEx():
    LogonUserEx()     



@pytest.mark.xfail
def test_LookupAccountName():
    LookupAccountName()     



@pytest.mark.xfail
def test_LookupAccountSid():
    LookupAccountSid()     



@pytest.mark.xfail
def test_LookupPrivilegeDisplayName():
    LookupPrivilegeDisplayName()     



@pytest.mark.xfail
def test_LookupPrivilegeName():
    LookupPrivilegeName()     



@pytest.mark.xfail
def test_LookupPrivilegeValue():
    LookupPrivilegeValue()     



@pytest.mark.xfail
def test_LsaAddAccountRights():
    LsaAddAccountRights()     



@pytest.mark.xfail
def test_LsaCallAuthenticationPackage():
    LsaCallAuthenticationPackage()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_LsaClose():
    LsaClose()     



def test_LsaConnectUntrusted():
    LsaConnectUntrusted()     



@pytest.mark.xfail
def test_LsaDeregisterLogonProcess():
    LsaDeregisterLogonProcess()     



@pytest.mark.xfail
def test_LsaEnumerateAccountRights():
    LsaEnumerateAccountRights()     



@pytest.mark.xfail
def test_LsaEnumerateAccountsWithUserRight():
    LsaEnumerateAccountsWithUserRight()     



def test_LsaEnumerateLogonSessions():
    LsaEnumerateLogonSessions()     



@pytest.mark.xfail
def test_LsaGetLogonSessionData():
    LsaGetLogonSessionData()     



@pytest.mark.xfail
def test_LsaLookupAuthenticationPackage():
    LsaLookupAuthenticationPackage()     



@pytest.mark.xfail
def test_LsaOpenPolicy():
    LsaOpenPolicy()     



@pytest.mark.xfail
def test_LsaQueryInformationPolicy():
    LsaQueryInformationPolicy()     



@pytest.mark.xfail
def test_LsaRegisterLogonProcess():
    LsaRegisterLogonProcess()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_LsaRegisterPolicyChangeNotification():
    LsaRegisterPolicyChangeNotification()     



@pytest.mark.xfail
def test_LsaRemoveAccountRights():
    LsaRemoveAccountRights()     



@pytest.mark.xfail
def test_LsaRetrievePrivateData():
    LsaRetrievePrivateData()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_LsaSetInformationPolicy():
    LsaSetInformationPolicy()     



@pytest.mark.xfail
def test_LsaStorePrivateData():
    LsaStorePrivateData()     



@pytest.mark.xfail
def test_LsaUnregisterPolicyChangeNotification():
    LsaUnregisterPolicyChangeNotification()     



@pytest.mark.xfail
def test_MapGenericMask():
    MapGenericMask()     



@pytest.mark.xfail
def test_OpenProcessToken():
    OpenProcessToken()     



@pytest.mark.xfail
def test_OpenThreadToken():
    OpenThreadToken()     



@pytest.mark.xfail
def test_QuerySecurityPackageInfo():
    QuerySecurityPackageInfo()     



def test_RevertToSelf():
    RevertToSelf()     



def test_SECURITY_ATTRIBUTES():
    SECURITY_ATTRIBUTES()     



def test_SECURITY_DESCRIPTOR():
    SECURITY_DESCRIPTOR()     



def test_SID():
    SID()     



@pytest.mark.xfail
def test_SetFileSecurity():
    SetFileSecurity()     



@pytest.mark.xfail
def test_SetKernelObjectSecurity():
    SetKernelObjectSecurity()     



@pytest.mark.xfail
def test_SetNamedSecurityInfo():
    SetNamedSecurityInfo()     



@pytest.mark.xfail
def test_SetSecurityInfo():
    SetSecurityInfo()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_SetThreadToken():
    SetThreadToken()     



@pytest.mark.xfail
def test_SetTokenInformation():
    SetTokenInformation()     



@pytest.mark.xfail
def test_SetUserObjectSecurity():
    SetUserObjectSecurity()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_TranslateName():
    TranslateName()     





import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32pipe import *
@pytest.mark.xfail
def test_CallNamedPipe():
    CallNamedPipe()     



@pytest.mark.xfail
def test_ConnectNamedPipe():
    ConnectNamedPipe()     



@pytest.mark.xfail
def test_CreateNamedPipe():
    CreateNamedPipe()     



@pytest.mark.xfail
def test_CreatePipe():
    CreatePipe()     



@pytest.mark.xfail
def test_DisconnectNamedPipe():
    DisconnectNamedPipe()     



@pytest.mark.xfail
def test_FdCreatePipe():
    FdCreatePipe()     



@pytest.mark.xfail
def test_GetNamedPipeClientProcessId():
    GetNamedPipeClientProcessId()     



@pytest.mark.xfail
def test_GetNamedPipeClientSessionId():
    GetNamedPipeClientSessionId()     



@pytest.mark.xfail
def test_GetNamedPipeHandleState():
    GetNamedPipeHandleState()     



@pytest.mark.xfail
def test_GetNamedPipeInfo():
    GetNamedPipeInfo()     



@pytest.mark.xfail
def test_GetNamedPipeServerProcessId():
    GetNamedPipeServerProcessId()     



@pytest.mark.xfail
def test_GetNamedPipeServerSessionId():
    GetNamedPipeServerSessionId()     



@pytest.mark.xfail
def test_GetOverlappedResult():
    GetOverlappedResult()     



@pytest.mark.xfail
def test_PeekNamedPipe():
    PeekNamedPipe()     



@pytest.mark.xfail
def test_SetNamedPipeHandleState():
    SetNamedPipeHandleState()     



@pytest.mark.xfail
def test_TransactNamedPipe():
    TransactNamedPipe()     



@pytest.mark.xfail
def test_WaitNamedPipe():
    WaitNamedPipe()     



@pytest.mark.xfail
def test_popen():
    popen()     



@pytest.mark.xfail
def test_popen2():
    popen2()     



@pytest.mark.xfail
def test_popen3():
    popen3()     



@pytest.mark.xfail
def test_popen4():
    popen4()     


